from random import choice
from .supportive_functions import (
    generate_female_name,
    generate_male_name,
    generate_surname_less,
    remove_duplicates,
)


female_prefix = [
    "aisha",
    "amal",
    "asra",
    "bahia",
    "dalila",
    "esma",
    "fadia",
    "ghada",
    "hala",
    "jalila",
    "kamila",
    "laila",
    "maha",
    "nadia",
    "omaira",
    "rabia",
    "sabah",
    "tamara",
    "yasmin",
    "zahra",
]

female_suffix = [
    "a",
    "ah",
    "at",
    "aya",
    "een",
    "ela",
    "ena",
    "era",
    "eya",
    "ia",
    "ida",
    "ina",
    "ira",
    "iya",
    "iyya",
    "iya",
    "iya",
    "iza",
    "ra",
    "ya",
]

male_prefix = [
    "ab",
    "ad",
    "ah",
    "al",
    "am",
    "an",
    "ar",
    "as",
    "az",
    "bah",
    "dal",
    "fah",
    "gha",
    "hab",
    "hak",
    "han",
    "has",
    "hay",
    "ibn",
    "id",
    "is",
    "ja",
    "kal",
    "kar",
    "kas",
    "lab",
    "mal",
    "mar",
    "nas",
    "rab",
    "rah",
    "sal",
    "sam",
    "sar",
    "sha",
    "tab",
    "tal",
    "tar",
    "yah",
    "yas",
    "zah",
    "zay",
]

male_suffix = [
    "ad",
    "ah",
    "al",
    "am",
    "an",
    "ar",
    "as",
    "at",
    "ay",
    "az",
    "dil",
    "din",
    "eem",
    "el",
    "en",
    "es",
    "ey",
    "id",
    "il",
    "im",
    "in",
    "ir",
    "is",
    "it",
    "iy",
    "iz",
    "lil",
    "mal",
    "mil",
    "min",
    "mir",
    "nir",
    "or",
    "os",
    "ur",
    "us",
    "ut",
    "uz",
]

surname_prefix = [
    "abd",
    "al",
    "am",
    "an",
    "ar",
    "ash",
    "asim",
    "az",
    "bah",
    "dal",
    "fah",
    "ghal",
    "ham",
    "has",
    "ibn",
    "jah",
    "kal",
    "kas",
    "mah",
    "naj",
    "qas",
    "ram",
    "saf",
    "sal",
    "sam",
    "tah",
    "zar",
]

surname_suffix = [
    "a",
    "ah",
    "at",
    "ay",
    "een",
    "i",
    "ia",
    "id",
    "il",
    "im",
    "ir",
    "is",
    "iy",
    "iyah",
    "ullah",
    "ulah",
    "ur",
    "us",
    "ush",
    "yah",
    "yid",
    "yim",
    "yin",
]

female_names = [
    "Abeer",
    "Abida",
    "Adila",
    "Afaf",
    "Ahlem",
    "Alia",
    "Amal",
    "Amani",
    "Amira",
    "Anwar",
    "Asma",
    "Aya",
    "Ayah",
    "Ayesha",
    "Aziza",
    "Badia",
    "Bahija",
    "Basma",
    "Dalia",
    "Dalila",
    "Dunia",
    "Fadia",
    "Fahima",
    "Farah",
    "Fatima",
    "Ghada",
    "Habiba",
    "Hadia",
    "Hala",
    "Hanan",
    "Hasna",
    "Hayat",
    "Hind",
    "Huda",
    "Iman",
    "Intisar",
    "Jamilah",
    "Kamila",
    "Kawthar",
    "Khadija",
    "Lamia",
    "Layla",
    "Lina",
    "Lubna",
    "Maha",
    "Mahira",
    "Malika",
    "Maram",
    "Mariam",
    "Maya",
    "Muna",
    "Nada",
    "Nadia",
    "Nadira",
    "Naima",
    "Nawal",
    "Noor",
    "Nora",
    "Rabab",
    "Rahma",
    "Rana",
    "Rania",
    "Rima",
    "Rouba",
    "Sabiha",
    "Sahar",
    "Salma",
    "Samia",
    "Sana",
    "Sara",
    "Shadia",
    "Shaima",
    "Shakira",
    "Shams",
    "Shaza",
    "Sherine",
    "Soraya",
    "Souad",
    "Suha",
    "Suhaila",
    "Sumaya",
    "Tahira",
    "Tasneem",
    "Wafa",
    "Widad",
    "Yasmin",
    "Yusra",
    "Zahra",
    "Zainab",
    "Zeina",
    "Zohra",
    "Zubaida",
]

male_names = [
    "Abdullah",
    "Abu Bakr",
    "Ahmad",
    "Aladdin",
    "Ali",
    "Amin",
    "Amir",
    "Anwar",
    "Asad",
    "Ashraf",
    "Ayman",
    "Aziz",
    "Bilal",
    "Dawud",
    "Faisal",
    "Farid",
    "Faruq",
    "Ghassan",
    "Hakim",
    "Hamid",
    "Harun",
    "Hasan",
    "Husam",
    "Husayn",
    "Ibrahim",
    "Idris",
    "Ihsan",
    "Imad",
    "Irfan",
    "Isa",
    "Isam",
    "Jamal",
    "Jibril",
    "Kamal",
    "Khalid",
    "Mahmoud",
    "Majid",
    "Malik",
    "Mansur",
    "Marwan",
    "Mazen",
    "Mehdi",
    "Muhammad",
    "Munir",
    "Mustafa",
    "Nadir",
    "Nasir",
    "Nizar",
    "Qasim",
    "Rashid",
    "Rauf",
    "Riyad",
    "Saad",
    "Sabir",
    "Saeed",
    "Salim",
    "Samir",
    "Tariq",
    "Usman",
    "Wahid",
    "Yahya",
    "Yasin",
    "Youssef",
    "Zaid",
    "Zaki",
    "Ziyad",
]

surnames = [
    "Abbas",
    "Abdullah",
    "Abu-Ghanem",
    "Ahmad",
    "Alawi",
    "Ali",
    "Amin",
    "Amir",
    "Ansari",
    "Arab",
    "Asad",
    "Ashraf",
    "Atiyah",
    "Awad",
    "Aziz",
    "Bakr",
    "Barakat",
    "Bazzi",
    "Daoud",
    "Dawood",
    "Fadel",
    "Fahd",
    "Faisal",
    "Farah",
    "Farhat",
    "Faruq",
    "Ghazali",
    "Haddad",
    "Hadi",
    "Hakim",
    "Halabi",
    "Hamad",
    "Hammad",
    "Hassan",
    "Husain",
    "Ibrahim",
    "Idris",
    "Imam",
    "Issa",
    "Jaber",
    "Jalal",
    "Jawad",
    "Kadhim",
    "Khalaf",
    "Khalid",
    "Khouri",
    "Majid",
    "Malik",
    "Mansour",
    "Maroun",
    "Matar",
    "Mazari",
    "Mehdi",
    "Mikhail",
    "Moawad",
    "Mohammad",
    "Mujahid",
    "Musa",
    "Mustafa",
    "Nader",
    "Najjar",
    "Nasir",
    "Nasser",
    "Nazir",
    "Omar",
    "Qasim",
    "Qureshi",
    "Rahman",
    "Rashid",
    "Sadiq",
    "Said",
    "Saleh",
    "Salim",
    "Samir",
    "Saqib",
    "Sharif",
    "Shihab",
    "Siddiq",
    "Suleiman",
    "Taha",
    "Talal",
    "Tamir",
    "Tariq",
    "Umar",
    "Usman",
    "Wahid",
    "Yahya",
    "Younes",
    "Yusuf",
    "Zaher",
    "Zaid",
    "Zain",
    "Zakaria",
    "Zaman",
    "Zayed",
    "Zuhair",
]

female = generate_female_name(female_prefix, female_suffix, min=1, max=2)
male = generate_male_name(male_prefix, male_suffix, min=1, max=2)
surname = generate_surname_less(surname_prefix, surname_suffix)

female_lbr = choice(female_names)
male_lbr = choice(male_names)
surname_lbr = choice(surnames)



from random import choice
from .supportive_functions import (
    generate_female_name,
    generate_male_name,
    generate_surname_less,
    remove_duplicates,
)

female_prefix = [
    "ac",
    "ae",
    "alb",
    "an",
    "ant",
    "aqui",
    "au",
    "avi",
    "ca",
    "ce",
    "ci",
    "clau",
    "clo",
    "co",
    "cor",
    "cu",
    "dea",
    "dec",
    "dom",
    "du",
    "eco",
    "ege",
    "emi",
    "ep",
    "er",
    "es",
    "eu",
    "fa",
    "fab",
    "fe",
    "fi",
    "fla",
    "fo",
    "fra",
    "ga",
    "ge",
    "gi",
    "gla",
    "gna",
    "go",
    "gra",
    "ha",
    "he",
    "her",
    "hi",
    "ho",
    "ia",
    "il",
    "im",
    "in",
    "io",
    "is",
    "ita",
    "ja",
    "je",
    "jo",
    "ju",
    "ka",
    "ke",
    "ki",
    "la",
    "le",
    "li",
    "lo",
    "lu",
    "ly",
    "ma",
    "me",
    "mi",
    "mo",
    "na",
    "ne",
    "ni",
    "no",
    "nu",
    "ny",
    "oa",
    "oe",
    "oi",
    "oia",
    "oiu",
    "pa",
    "pe",
    "pi",
    "po",
    "pra",
    "pre",
    "pri",
    "pro",
    "qua",
    "que",
    "qui",
    "quo",
    "ra",
    "re",
    "ri",
    "ro",
    "ru",
    "ry",
    "sa",
    "se",
    "si",
    "so",
    "su",
    "sy",
    "ta",
    "te",
    "ti",
    "to",
    "tu",
    "ty",
    "ua",
    "ue",
    "ui",
    "ula",
    "ule",
    "uli",
    "ulo",
    "uma",
    "ume",
    "umi",
    "umo",
    "una",
    "une",
    "uni",
    "uno",
    "ura",
    "ure",
    "uri",
    "uro",
    "usa",
    "use",
    "usi",
    "uso",
    "uta",
    "ute",
    "uti",
    "uto",
    "va",
    "ve",
    "vi",
    "vo",
    "vu",
    "vy",
    "xa",
    "xe",
    "xi",
    "xo",
    "xu",
    "xy",
    "ya",
    "ye",
    "yi",
    "yo",
    "yu",
    "zy",
]

female_suffix = [
    "ana",
    "antia",
    "astra",
    "atia",
    "avia",
    "cilia",
    "cla",
    "dia",
    "dina",
    "drus",
    "ea",
    "ecia",
    "elia",
    "ena",
    "era",
    "eria",
    "eta",
    "ia",
    "iana",
    "icca",
    "icia",
    "ida",
    "ilia",
    "ina",
    "inia",
    "iola",
    "ita",
    "la",
    "lia",
    "lina",
    "lita",
    "lo",
    "lusa",
    "ma",
    "mia",
    "na",
    "nia",
    "nilla",
    "nona",
    "ona",
    "onia",
    "ora",
    "oria",
    "ula",
    "ulla",
    "una",
    "usa",
    "uta",
    "via",
    "ya",
]

male_prefix = [
    "ae",
    "al",
    "an",
    "au",
    "ca",
    "ci",
    "co",
    "cu",
    "d",
    "da",
    "de",
    "di",
    "do",
    "ea",
    "ee",
    "ei",
    "eo",
    "eu",
    "fa",
    "fe",
    "fi",
    "fo",
    "fu",
    "ga",
    "ge",
    "gi",
    "go",
    "gu",
    "ha",
    "he",
    "hi",
    "ho",
    "ia",
    "ie",
    "ii",
    "io",
    "iu",
    "ja",
    "je",
    "ji",
    "jo",
    "ju",
    "la",
    "le",
    "li",
    "lo",
    "lu",
    "ma",
    "me",
    "mi",
    "mo",
    "mu",
    "na",
    "ne",
    "ni",
    "no",
    "nu",
    "oa",
    "oe",
    "oi",
    "oo",
    "ou",
    "p",
    "pa",
    "pe",
    "pi",
    "po",
    "pu",
    "q",
    "qa",
    "qe",
    "qi",
    "qo",
    "qu",
    "r",
    "ra",
    "re",
    "ri",
    "ro",
    "ru",
    "sa",
    "se",
    "si",
    "so",
    "su",
    "ta",
    "te",
    "ti",
    "to",
    "tu",
    "ua",
    "ue",
    "ui",
    "uo",
    "uu",
    "va",
    "ve",
    "vi",
    "vo",
    "vu",
    "xa",
    "xe",
    "xi",
    "xo",
    "xu",
    "za",
    "ze",
    "zi",
    "zo",
    "zu",
]

male_suffix = ["ian", "ianus", "ius", "o", "us"]

surname_prefix = [
    "aqui",
    "au",
    "brut",
    "caec",
    "cass",
    "cecil",
    "claud",
    "cornel",
    "fab",
    "flav",
    "gai",
    "gal",
    "juli",
    "licin",
    "lucret",
    "maec",
    "marc",
    "max",
    "metell",
    "octav",
    "paul",
    "pomp",
    "quinct",
    "sulp",
    "tiber",
    "valer",
    "vips",
]

surname_suffix = [
    "anus",
    "ellus",
    "enius",
    "enus",
    "ianus",
    "ienus",
    "illus",
    "inus",
    "ius",
    "us",
]

female_names = [
    "Aburia",
    "Accoleia",
    "Acilia",
    "Aebutia",
    "Aelia",
    "Aemilia",
    "Afrania",
    "Agrippina",
    "Alba",
    "Albina",
    "Alfidia",
    "Annalis",
    "Anteia",
    "Antestia",
    "Antonia",
    "Antullia",
    "Apollonia",
    "Aponia",
    "Appia",
    "Aquila",
    "Aricia",
    "Arria",
    "Aruntia",
    "Ateria",
    "Atia",
    "Atinia",
    "Attia",
    "Aufidia",
    "Aulia",
    "Aurelia",
    "Auria",
    "Aventina",
    "Avidia",
    "Aviena",
    "Avita",
    "Axia",
    "Baebia",
    "Baebiana",
    "Balbina",
    "Barbula",
    "Bebia",
    "Blandia",
    "Bolanilla",
    "Caecilia",
    "Caesennia",
    "Caesia",
    "Caetronia",
    "Caia",
    "Calavia",
    "Caldonia",
    "Calena",
    "Calidia",
    "Callistia",
    "Calpurnia",
    "Calventia",
    "Camilla",
    "Cantia",
    "Canuleia",
    "Carfulena",
    "Carisia",
    "Carvilia",
    "Cassia",
    "Cassiana",
    "Cassidia",
    "Cassilia",
    "Cassulia",
    "Ceria",
    "Cethegilla",
    "Chresta",
    "Clara",
    "Claudia",
    "Claudina",
    "Clelia",
    "Clodia",
    "Cloelia",
    "Cluentia",
    "Coelia",
    "Cominia",
    "Cordia",
    "Cornelia",
    "Cossinia",
    "Crispina",
    "Curia",
    "Curtia",
    "Decidia",
    "Decima",
    "Decimia",
    "Decumia",
    "Decundia",
    "Decuria",
    "Dentidia",
    "Domitia",
    "Drusilla",
    "Egnatia",
    "Equitia",
    "Esperia",
    "Etruria",
    "Eudocia",
    "Fabia",
    "Fabricia",
    "Fadia",
    "Faltonia",
    "Fannia",
    "Farsuleia",
    "Faucia",
    "Fausta",
    "Firmia",
    "Flaccidia",
    "Flaminia",
    "Flavia",
    "Flaviana",
    "Flavilia",
    "Fonteia",
    "Foslia",
    "Fufia",
    "Fuficia",
    "Fulcinia",
    "Fulvia",
    "Fulvina",
    "Furia",
    "Galba",
    "Galeria",
    "Gallia",
    "Gavia",
    "Gegania",
    "Gellia",
    "Genucia",
    "Glabia",
    "Grania",
    "Gratidia",
    "Helena",
    "Helvia",
    "Herennia",
    "Hirtia",
    "Horatia",
    "Hortensia",
    "Hosidia",
    "Hostilia",
    "Hosulia",
    "I",
    "Ignatia",
    "Ilicia",
    "Incita",
    "Ingenua",
    "Insteia",
    "Isinia",
    "Iunia",
    "Julia",
    "Junia",
    "Laelia",
    "Lavinia",
    "Licinia",
    "Lollia",
    "Lucia",
    "Lucretia",
    "Maelia",
    "Marcia",
    "Maxima",
    "Minucia",
    "Nona",
    "Octavia",
    "Papiria",
    "Paulina",
    "Petronia",
    "Pompeia",
    "Porcia",
    "Prisca",
    "Pulla",
    "Quarta",
    "Quintia",
    "Regina",
    "Rubellia",
    "Rufia",
    "Sabina",
    "Sallustia",
    "Secundina",
    "Septima",
    "Servilia",
    "Sextilia",
    "Silvia",
    "Sulpicia",
    "Tertia",
    "Tullia",
    "Ulia",
    "Valeria",
    "Verginia",
    "Vibia",
    "Vinicia",
    "Vipsania",
    "Vistilia",
    "Vitellia",
    "Volumnia",
    "Volusa",
    "Vopisca",
]

male_names = [
    "Achilles",
    "Actius",
    "Adrianus",
    "Aelianus",
    "Aelius",
    "Agrippa",
    "Agrippinus",
    "Albinus",
    "Alexandrus",
    "Amulius",
    "Andronicus",
    "Anicius",
    "Antoninus",
    "Antonius",
    "Apollinaris",
    "Apollonius",
    "Aquilinus",
    "Arcadius",
    "Aristotle",
    "Atticus",
    "Augustus",
    "Aulus",
    "Aurelian",
    "Aureolus",
    "Aventinus",
    "Balbinus",
    "Balbus",
    "Barbarus",
    "Barbatus",
    "Bassus",
    "Blasius",
    "Brutus",
    "Caecilius",
    "Caius",
    "Caligula",
    "Calpurnius",
    "Carpophorus",
    "Carus",
    "Cassian",
    "Cassius",
    "Cato",
    "Catullus",
    "Celer",
    "Celsus",
    "Cerealis",
    "Chrysogonus",
    "Cicero",
    "Claudian",
    "Claudianus",
    "Claudius",
    "Clemens",
    "Commodus",
    "Constantinus",
    "Cornelis",
    "Cornelius",
    "Corvinus",
    "Crispus",
    "Cyprianus",
    "Damianus",
    "Decentius",
    "Decimus",
    "Didius",
    "Dionysius",
    "Dolabella",
    "Domitian",
    "Donatus",
    "Draco",
    "Drusillus",
    "Drusus",
    "Egnatius",
    "Eustachius",
    "Fabius",
    "Felix",
    "Festus",
    "Flaccus",
    "Flaminius",
    "Fulgentius",
    "Gaius",
    "Galba",
    "Gellius",
    "Geminus",
    "Germanicus",
    "Gordianus",
    "Gratian",
    "Hadrian",
    "Hadrianus",
    "Hector",
    "Heliogabalus",
    "Helvius",
    "Herennius",
    "Herodes",
    "Hilarus",
    "Honorius",
    "Horatius",
    "Hortensius",
    "Hostilian",
    "Hymenaeus",
    "Iovianus",
    "Isidorus",
    "Jovinus",
    "Juba",
    "Julian",
    "Julius",
    "Junius",
    "Justinianus",
    "Justus",
    "Juvenalis",
    "Laelius",
    "Laurentius",
    "Leo",
    "Lepidus",
    "Licinianus",
    "Licinius",
    "Livius",
    "Longinus",
    "Lucianus",
    "Lucius",
    "Lucullus",
    "Lupus",
    "Lycomedes",
    "Macarius",
    "Maelius",
    "Magnus",
    "Majorianus",
    "Marcellinus",
    "Marcellus",
    "Marcus",
    "Marius",
    "Maurus",
    "Maxentius",
    "Maximus",
    "Melissus",
    "Mellitus",
    "Miltiades",
    "Montanus",
    "Nepos",
    "Neratius",
    "Nero",
    "Nicanor",
    "Niger",
    "Nonius",
    "Numerius",
    "Octavianus",
    "Octavius",
    "Olympius",
    "Opellius",
    "Orontius",
    "Ostorianus",
    "Otho",
    "Ovidius",
    "Palatinus",
    "Pansa",
    "Parthenius",
    "Patroclus",
    "Paulus",
    "Pelagius",
    "Pertinax",
    "Philemon",
    "Pius",
    "Placidus",
    "Plautus",
    "Pliny",
    "Pollux",
    "Pompeius",
    "Pontianus",
    "Postumus",
    "Priscus",
    "Probus",
    "Proclus",
    "Proculus",
    "Prudentius",
    "Pudens",
    "Quintianus",
    "Quintilian",
    "Quintillus",
    "Quintus",
    "Rabanus",
    "Rebilus",
    "Regalianus",
    "Regulus",
    "Remus",
    "Rogatus",
    "Romulus",
    "Rufinus",
    "Rufus",
    "Sabinus",
    "Saturninus",
    "Scaevola",
    "Scipio",
    "Sejanus",
    "Seneca",
    "Septimius",
    "Septimus",
    "Servius",
    "Severianus",
    "Severus",
    "Sextilianus",
    "Sextus",
    "Silvanus",
    "Solinus",
    "Sosigenes",
    "Spartacus",
    "Stephanus",
    "Tacitus",
    "Terentius",
    "Tertius",
    "Tertullus",
    "Theodosius",
    "Thracius",
    "Thrasea",
    "Tiberius",
    "Titus",
    "Traianus",
    "Trajan",
    "Trebonius",
    "Tullius",
    "Urbanus",
    "Valens",
    "Valentinus",
    "Valerius",
    "Varius",
    "Varro",
    "Verus",
    "Vespasian",
    "Vetranio",
    "Vibius",
    "Victorinus",
    "Vindex",
    "Vitalis",
    "Vitellius",
    "Vitruvius",
    "Vivianus",
    "Volusianus",
    "Xenophon",
    "Zeno",
    "Zephyrinus",
    "Zoticus",
]

surnames = [
    "Acilius",
    "Aemilius",
    "Albinus",
    "Antonius",
    "Appius",
    "Aquila",
    "Aquilinus",
    "Atilius",
    "Aurelius",
    "Balbus",
    "Barbatus",
    "Bassus",
    "Blasius",
    "Brutus",
    "Caecilius",
    "Caecus",
    "Caesar",
    "Calpurnius",
    "Capito",
    "Carus",
    "Cassius",
    "Cato",
    "Celer",
    "Cicero",
    "Cinna",
    "Claudius",
    "Cnadius",
    "Cornelius",
    "Crispus",
    "Decimus",
    "Didius",
    "Dolabella",
    "Domitianus",
    "Dossenus",
    "Drusus",
    "Fabius",
    "Festus",
    "Flavius",
    "Gaius",
    "Galerius",
    "Gallio",
    "Gallus",
    "Gavius",
    "Germanicus",
    "Geta",
    "Glabrio",
    "Gracchus",
    "Gratianus",
    "Hadrianus",
    "Hirtius",
    "Honorius",
    "Horatius",
    "Julius",
    "Junius",
    "Juvenalis",
    "Laelius",
    "Laevinus",
    "Lentulus",
    "Lepidus",
    "Licinius",
    "Ligarius",
    "Livius",
    "Longinus",
    "Lucilius",
    "Macer",
    "Macrinus",
    "Mallius",
    "Mamercus",
    "Marcellus",
    "Marius",
    "Maro",
    "Marullus",
    "Maxentius",
    "Maximus",
    "Messala",
    "Messius",
    "Metellus",
    "Modestus",
    "Naevius",
    "Nero",
    "Nerva",
    "Nigidius",
    "Ocella",
    "Octavius",
    "Orfitus",
    "Otho",
    "Paetus",
    "Papirius",
    "Paulus",
    "Pertinax",
    "Petronius",
    "Philo",
    "Plancus",
    "Plinius",
    "Pompeius",
    "Porcius",
    "Postumus",
    "Pudens",
    "Quadratus",
    "Quintilius",
    "Quirinius",
    "Regillus",
    "Regulus",
    "Rubellius",
    "Rufinus",
    "Rufus",
    "Scaevola",
    "Scipio",
    "Scribonius",
    "Sejanus",
    "Seneca",
    "Senecio",
    "Severus",
    "Sextus",
    "Silanus",
    "Silius",
    "Silus",
    "Spinther",
    "Tacitus",
    "Tarpeius",
    "Tertius",
    "Tertullus",
    "Theodosius",
    "Theon",
    "Tiberius",
    "Titius",
    "Torquatus",
    "Traianus",
    "Trogus",
    "Tullius",
    "Ulpianus",
    "Urbicus",
    "Valens",
    "Valerius",
    "Varius",
    "Vatinius",
    "Vergilius",
    "Verus",
    "Vespasianus",
    "Vibius",
    "Vindex",
    "Vipsanius",
    "Vitellius",
    "Vitruvius",
    "Vulcanius",
    "Vulso",
    "Zeno",
    "Zephyrinus",
]

female = generate_female_name(female_prefix, female_suffix, min=1, max=1)
male = generate_male_name(male_prefix, male_suffix, min=1, max=1)
surname = generate_surname_less(surname_prefix, surname_suffix)

female_lbr = choice(female_names)
male_lbr = choice(male_names)
surname_lbr = choice(surnames)



from random import choice
from .supportive_functions import (
    generate_female_name,
    generate_male_name,
    generate_surname_less,
    remove_duplicates,
)


female_prefix = [
    "ba",
    "be",
    "bol",
    "chi",
    "da",
    "dor",
    "e",
    "en",
    "ga",
    "ge",
    "go",
    "je",
    "ji",
    "ka",
    "ke",
    "la",
    "le",
    "lu",
    "ma",
    "me",
    "mo",
    "na",
    "ne",
    "o",
    "on",
    "sa",
    "se",
    "so",
    "su",
    "ta",
    "te",
    "to",
    "tu",
    "u",
    "un",
    "ya",
    "yo",
]

female_suffix = [
    "a",
    "aa",
    "ai",
    "ami",
    "an",
    "ara",
    "ari",
    "ariya",
    "ay",
    "bayar",
    "bileg",
    "bish",
    "bolor",
    "dari",
    "delger",
    "dolgor",
    "dorj",
    "dzaya",
    "e",
    "ei",
    "en",
    "ena",
    "ergui",
    "gerel",
    "guya",
    "jargal",
    "jirim",
    "khatan",
    "khulan",
    "mend",
    "munkh",
    "naran",
    "nomin",
    "nur",
    "nyam",
    "nyamaa",
    "od",
    "oldoo",
    "orgil",
    "sar",
    "sarnai",
    "sodnom",
    "suvdaa",
    "temuujin",
    "tsetseg",
    "tulga",
    "tuya",
    "ulan",
    "undur",
    "unurtsetseg",
    "uyanga",
    "yagaan",
    "yasu",
    "yo",
    "yonjoo",
    "zaya",
    "zolboo",
]

male_prefix = [
    "ba",
    "ban",
    "bay",
    "bod",
    "bol",
    "bor",
    "bul",
    "da",
    "dag",
    "del",
    "dor",
    "du",
    "dul",
    "dun",
    "ga",
    "gan",
    "gard",
    "ge",
    "ger",
    "gur",
    "ho",
    "hor",
    "hun",
    "huu",
    "in",
    "ir",
    "ja",
    "jam",
    "je",
    "jir",
    "jiy",
    "khad",
    "khur",
    "khuu",
    "ma",
    "mar",
    "mend",
    "mur",
    "na",
    "nam",
    "nor",
    "nur",
    "od",
    "old",
    "ond",
    "or",
    "sai",
    "saihan",
    "sod",
    "sor",
    "su",
    "sukh",
    "tum",
    "tuv",
    "ug",
    "und",
    "ur",
    "usk",
    "zor",
]

male_suffix = [
    "baatar",
    "bazar",
    "bold",
    "dai",
    "dorj",
    "erdene",
    "gal",
    "gan",
    "gerel",
    "gur",
    "khuu",
    "la",
    "mandakh",
    "mur",
    "nyam",
    "od",
    "old",
    "ondor",
    "orgil",
    "sai",
    "saihan",
    "sod",
    "tum",
    "tuv",
    "undari",
    "ur",
    "usk",
    "zayaa",
]

surname_prefix = [
    "bai",
    "bat",
    "bata",
    "bold",
    "chulu",
    "dash",
    "dava",
    "erd",
    "gana",
    "gant",
    "jav",
    "jarg",
    "khun",
    "khuu",
    "munkh",
    "naran",
    "nyam",
    "ochir",
    "orgil",
    "sukh",
    "tug",
    "tulga",
    "tuv",
    "ugan",
    "undrakh",
    "urtna",
    "yond",
    "zaya",
]

surname_suffix = [
    "aa",
    "baatar",
    "bileg",
    "bolor",
    "chimeg",
    "delger",
    "dorj",
    "gerel",
    "gurav",
    "hongor",
    "jargal",
    "khand",
    "khishig",
    "maa",
    "nar",
    "nasan",
    "ochir",
    "orkh",
    "saihan",
    "sambuu",
    "tsetseg",
    "tseren",
    "tsetse",
    "tuguldur",
    "ulan",
    "undrakh",
    "urt",
    "zorig",
]

female_names = [
    "Altantsetseg",
    "Anu",
    "Ariun",
    "Arslan",
    "Batu",
    "Bekh",
    "Bileg",
    "Bulgan",
    "Börte",
    "Chagatai",
    "Dalai",
    "Dorje",
    "Erdene",
    "Esenge",
    "Ganga",
    "Gelug",
    "Gobi",
    "Güyük",
    "Jochi",
    "Khadan",
    "Khatan",
    "Khorlo",
    "Khulan",
    "Kublai",
    "Kulan",
    "Lhama",
    "Mandukhai",
    "Mönkh",
    "Naran",
    "Nergüi",
    "Noyon",
    "Odchigin",
    "Odon",
    "Oirad",
    "Ondor",
    "Orlok",
    "Oyun",
    "Qutuqtu",
    "Rinchen",
    "Saldar",
    "Sarnai",
    "Sechen",
    "Sengge",
    "Seren",
    "Sorkhaqtani",
    "Tenger",
    "Toghril",
    "Töregene",
    "Ujin",
    "Ulaan",
    "Urtu",
    "Yesui",
    "Yisügei",
    "Yuden",
    "Zaya",
    "Zaya Pandita",
    "Zayayin",
    "Zereg",
    "Zhenjin",
    "Zulaykha",
    "Zurgadai",
    "Zvun",
    "Züünbayan",
    "Züüngar",
    "Ögedei",
    "Öndör",
    "Özübek",
]

male_names = [
    "Altan",
    "Amarsanaa",
    "Arban",
    "Bataar",
    "Batbayar",
    "Batbold",
    "Batu",
    "Bayaraa",
    "Bileg",
    "Bogd",
    "Bolormaa",
    "Buyan",
    "Chinua",
    "Dambi",
    "Danzanravjaa",
    "Davaa",
    "Delger",
    "Demberel",
    "Dorj",
    "Enebish",
    "Erdene",
    "Erdeni",
    "Galdan",
    "Ganbaatar",
    "Ganbold",
    "Ganzorig",
    "Genghis",
    "Jabkhai",
    "Jamukha",
    "Jangar",
    "Jargal",
    "Javkhlantugs",
    "Jugder",
    "Khan",
    "Khorloo",
    "Khulan",
    "Khurelbaatar",
    "Kublai",
    "Lkhagva",
    "Mandukhai",
    "Mendbayar",
    "Mendee",
    "Naran",
    "Nergui",
    "Noyon",
    "Ochir",
    "Od",
    "Odon",
    "Onon",
    "Oyun",
    "Oyuntsetseg",
    "Puntsag",
    "Sengge",
    "Sodnom",
    "Suhbaatar",
    "Surendraa",
    "Toghrul",
    "Tsakhiagiin",
    "Tsetseg",
    "Tsogt",
    "Tumen",
    "Tuvshin",
    "Uchral",
    "Ulaan",
    "Ulzi",
    "Undraa",
    "Urgyen",
    "Urtnasan",
    "Uuganbaatar",
    "Yondon",
    "Yudhisthira",
    "Zanabazar",
    "Zorig",
]

surnames = [
    "Ariq",
    "Baatar",
    "Bagatur",
    "Bataar",
    "Bayan",
    "Bekh",
    "Borte",
    "Buka",
    "Burkhan",
    "Chinggis",
    "Dai",
    "Dalai",
    "Danzan",
    "Darhan",
    "Dashi",
    "Delger",
    "Doljin",
    "Dorji",
    "Duwa",
    "Eke",
    "Erdeni",
    "Ghenghis",
    "Gobi",
    "Gombodorj",
    "Gurkhan",
    "Hachi",
    "Hada",
    "Hasar",
    "Horijin",
    "Ideriin",
    "Ilgei",
    "Jabkha",
    "Jalair",
    "Jigjid",
    "Jugder",
    "Kachi",
    "Kadan",
    "Khanuy",
    "Khorlo",
    "Khubilai",
    "Khukh",
    "Khun",
    "Khutulun",
    "Kokochu",
    "Konchok",
    "Lhamo",
    "Mandukhai",
    "Modu",
    "Mongke",
    "Naiman",
    "Naran",
    "Nergui",
    "Norbu",
    "Ogedei",
    "Oljei",
    "Onon",
    "Ord",
    "Orlok",
    "Orten",
    "Otgon",
    "Padma",
    "Qasar",
    "Qorchi",
    "Rashid",
    "Sain",
    "Senge",
    "Shagdaryn",
    "Sodnom",
    "Sonam",
    "Sorkhon",
    "Suld",
    "Sungari",
    "Tabun",
    "Tengger",
    "Toghril",
    "Tughrul",
    "Tumen",
    "Turgen",
    "Tuya",
    "Ujin",
    "Ulaan",
    "Ulziit",
    "Unen",
    "Urgen",
    "Usukh",
    "Utka",
    "Yelü",
    "Yesugei",
    "Yisügei",
    "Yuden",
    "Zaya",
    "Zayat",
    "Zorig",
]

female = generate_female_name(female_prefix, female_suffix, min=1, max=1)
male = generate_male_name(male_prefix, male_suffix, min=1, max=1)
surname = generate_surname_less(surname_prefix, surname_suffix)

female_lbr = choice(female_names)
male_lbr = choice(male_names)
surname_lbr = choice(surnames)



from random import choice
from .supportive_functions import (
    generate_female_name,
    generate_male_name,
    generate_surname,
    remove_duplicates,
)


female_prefix = [
    "bal",
    "da",
    "din",
    "dur",
    "fal",
    "gim",
    "gin",
    "gor",
    "hel",
    "in",
    "kil",
    "li",
    "mha",
    "na",
    "nin",
    "ran",
    "sha",
    "thor",
    "tha",
    "zin",
]

female_suffix = [
    "ǎ",
    "dǎ",
    "del",
    "dûr",
    "fa",
    "ga",
    "gal",
    "gan",
    "gard",
    "hild",
    "in",
    "kil",
    "la",
    "lda",
    "lin",
    "ma",
    "mi",
    "na",
    "ra",
    "ri",
    "sa",
    "thi",
    "thra",
    "zǎ",
]


male_prefix = [
    "az",
    "bal",
    "bor",
    "da",
    "dor",
    "du",
    "fa",
    "gar",
    "gim",
    "glo",
    "gra",
    "grom",
    "han",
    "hur",
    "kaz",
    "kil",
    "knar",
    "kri",
    "lur",
    "mak",
    "mor",
    "nar",
    "nor",
    "ri",
    "rok",
    "run",
    "thor",
    "thra",
    "thu",
    "ul",
    "ur",
    "var",
    "vōr",
]

male_suffix = [
    "ain",
    "ǎk",
    "ar",
    "bar",
    "bor",
    "dain",
    "dal",
    "din",
    "dûr",
    "fin",
    "gǎrn",
    "gar",
    "gim",
    "gorn",
    "grim",
    "gûn",
    "gûr",
    "in",
    "kil",
    "korn",
    "li",
    "lin",
    "mar",
    "mir",
    "nar",
    "nûr",
    "rik",
    "rim",
    "rin",
    "ron",
    "rum",
    "thōr",
    "thrin",
    "thûr",
    "um",
    "ûr",
    "var",
    "zin",
]


surname_syllables = [
    "bar",
    "bif",
    "bin",
    "bor",
    "bǎl",
    "dal",
    "dar",
    "dur",
    "fal",
    "fin",
    "gar",
    "gim",
    "gin",
    "gon",
    "gor",
    "grim",
    "gun",
    "gur",
    "har",
    "kar",
    "kaz",
    "khaz",
    "kil",
    "kin",
    "kram",
    "kōr",
    "lok",
    "lor",
    "mag",
    "mak",
    "mar",
    "mir",
    "mur",
    "nar",
    "nim",
    "nor",
    "nûr",
    "rag",
    "rig",
    "rik",
    "rim",
    "ror",
    "rum",
    "tar",
    "thar",
    "thor",
    "thrak",
    "thran",
    "thrur",
    "tor",
    "tur",
    "ur",
    "vol",
    "vor",
]

female_names = [
    "Adrelda",
    "Aldith",
    "Alfhilda",
    "Angrvadis",
    "Arlun",
    "Arvis",
    "Averi",
    "Azska",
    "Baldis",
    "Beldrith",
    "Berga",
    "Berna",
    "Bofri",
    "Brenna",
    "Brimja",
    "Brindis",
    "Brynva",
    "Dagna",
    "Dagnis",
    "Daira",
    "Dalfa",
    "Darrhild",
    "Disja",
    "Djorvi",
    "Dolvi",
    "Dorina",
    "Drenna",
    "Eikva",
    "Elinva",
    "Elma",
    "Embla",
    "Erlina",
    "Faldra",
    "Falja",
    "Firna",
    "Fliss",
    "Frisa",
    "Fylra",
    "Gilda",
    "Gimra",
    "Glindis",
    "Glira",
    "Gorva",
    "Grerda",
    "Grista",
    "Gundis",
    "Gurdis",
    "Gyla",
    "Hadra",
    "Halda",
    "Hamfa",
    "Hervis",
    "Hilda",
    "Hjordis",
    "Hulda",
    "Hulna",
    "Ilma",
    "Imara",
    "Inga",
    "Ingva",
    "Irdra",
    "Jarna",
    "Jofri",
    "Kadra",
    "Kara",
    "Kelda",
    "Kessa",
    "Kilda",
    "Lifa",
    "Lofa",
    "Lyra",
    "Mara",
    "Marni",
    "Milda",
    "Mundis",
    "Nessa",
    "Nidra",
    "Nistra",
    "Norva",
    "Nyra",
    "Odfri",
    "Odna",
    "Olfra",
    "Olva",
    "Orva",
    "Radra",
    "Ragna",
    "Raina",
    "Reinva",
    "Rika",
    "Rinda",
    "Risva",
    "Rivra",
    "Rofri",
    "Rohilda",
    "Runva",
    "Saga",
    "Sigdha",
    "Sigfrida",
    "Siguna",
    "Sindri",
    "Sofra",
    "Solva",
    "Svinva",
    "Synva",
    "Tarja",
    "Theldis",
    "Thelma",
    "Therda",
    "Theris",
    "Thilda",
    "Thora",
    "Threna",
    "Thrista",
    "Thrunva",
    "Tindra",
    "Torva",
    "Trisja",
    "Tryska",
    "Tulda",
    "Unna",
    "Urdra",
    "Valdra",
    "Valma",
    "Vanda",
    "Vangra",
    "Vanva",
    "Varda",
    "Vedra",
    "Veigdis",
    "Verna",
    "Vilda",
    "Vindra",
    "Vinva",
    "Viska",
    "Ylva",
    "Yndra",
    "Yrsa",
    "Ystris",
    "Yurga",
    "Yvinva",
    "Zadra",
    "Zelda",
    "Zessa",
    "Zilda",
    "Zorva",
    "Zyna",
]

male_names = [
    "Adrik",
    "Adrok",
    "Agnor",
    "Aldon",
    "Alrik",
    "Amgar",
    "Angrim",
    "Anvid",
    "Ardon",
    "Argor",
    "Argrin",
    "Arin",
    "Aurin",
    "Axur",
    "Azag",
    "Balder",
    "Balin",
    "Balrik",
    "Barag",
    "Bardin",
    "Barin",
    "Beldor",
    "Belgin",
    "Bofur",
    "Borin",
    "Bralin",
    "Brannar",
    "Brogan",
    "Brogar",
    "Burgur",
    "Burin",
    "Dagin",
    "Dain",
    "Daldor",
    "Dalin",
    "Dargor",
    "Dargur",
    "Deknar",
    "Delgar",
    "Delin",
    "Dolgar",
    "Dolrik",
    "Dorgrim",
    "Dorin",
    "Dragnar",
    "Drar",
    "Dromir",
    "Dror",
    "Dugrim",
    "Dugur",
    "Durin",
    "Dwalin",
    "Edrik",
    "Einar",
    "Eldor",
    "Eldrak",
    "Eldrin",
    "Elrik",
    "Elrin",
    "Eramir",
    "Erdin",
    "Faldin",
    "Faldor",
    "Fardin",
    "Farin",
    "Fili",
    "Folgar",
    "Forin",
    "Frar",
    "Frodin",
    "Frorin",
    "Galar",
    "Gandalf",
    "Gandor",
    "Garor",
    "Gildor",
    "Gimlar",
    "Gimli",
    "Gorim",
    "Gorin",
    "Goror",
    "Gragnar",
    "Grimbur",
    "Grimrik",
    "Gror",
    "Grorin",
    "Gundin",
    "Gunin",
    "Harin",
    "Harinor",
    "Hofar",
    "Hornar",
    "Hugin",
    "Hurgar",
    "Hurin",
    "Ingmar",
    "Ingold",
    "Ironar",
    "Ironin",
    "Kagor",
    "Kagrim",
    "Kalin",
    "Kalinor",
    "Kilin",
    "Kilinor",
    "Kragar",
    "Kragin",
    "Kromar",
    "Kromir",
    "Lodin",
    "Lofar",
    "Lorag",
    "Lorin",
    "Magnar",
    "Mardin",
    "Mardinor",
    "Morgrim",
    "Morin",
    "Nain",
    "Narag",
    "Nardor",
    "Nargor",
    "Nildor",
    "Noldar",
    "Nordin",
    "Nordinor",
    "Norin",
    "Norinor",
    "Ogdar",
    "Ogmar",
    "Orgrim",
    "Orin",
    "Orinor",
    "Othgar",
    "Ragnar",
    "Ragnor",
    "Ralgar",
    "Ramir",
    "Rogar",
    "Rogrim",
    "Rorim",
    "Rorin",
    "Sagor",
    "Sagrim",
    "Thaldin",
    "Thalgur",
    "Tharag",
    "Thardin",
    "Tharin",
    "Thoran",
    "Thorgar",
    "Thorin",
    "Thorinor",
    "Thralin",
    "Thromir",
    "Thror",
    "Thurim",
    "Thurin",
    "Torag",
    "Torin",
    "Ulfgar",
    "Ulrik",
    "Urdin",
    "Urdor",
    "Uthgar",
    "Uthor",
    "Varag",
    "Varin",
    "Vorag",
    "Vorin",
    "Yagor",
    "Yaldir",
    "Yamin",
    "Yaminor",
    "Yodrin",
    "Yorag",
    "Yorin",
    "Zagin",
    "Zagor",
    "Zangar",
    "Zangrim",
    "Zodrin",
    "Zogar",
    "Zogrim",
    "Zorin",
    "Zurgar",
]

surnames = [
    "Amberheart",
    "Amberstone",
    "Ashenbrow",
    "Ashenmantle",
    "Ashenshield",
    "Ashenstone",
    "Ashenvein",
    "Axbasher",
    "Axebringer",
    "Axeforge",
    "Axeheart",
    "Bitterpick",
    "Blackbranch",
    "Blackforge",
    "Blackhand",
    "Blacklock",
    "Blackmantle",
    "Blackrock",
    "Blackstone",
    "Blackvein",
    "Bouldershield",
    "Boulderstone",
    "Coalforge",
    "Cragmail",
    "Cragspine",
    "Cragstone",
    "Darkhammer",
    "Deepdelve",
    "Deepdelver",
    "Deepforge",
    "Deepminer",
    "Deepstone",
    "Doomhelm",
    "Dragonforge",
    "Dragonheart",
    "Earthbreaker",
    "Earthshaker",
    "Earthshaper",
    "Earthshard",
    "Earthsmith",
    "Earthstone",
    "Earthward",
    "Earthwhisper",
    "Emberbeard",
    "Emberspark",
    "Emberstone",
    "Firebrand",
    "Fireforge",
    "Fireheart",
    "Firestrike",
    "Firethane",
    "Fireward",
    "Flamebeard",
    "Flameforge",
    "Frostbeard",
    "Frostbranch",
    "Frostmane",
    "Gemsunder",
    "Gemsunderer",
    "Gemtamer",
    "Gildedhelm",
    "Glimmerbeard",
    "Glowforge",
    "Goldengrip",
    "Goldenmantle",
    "Goldenshaper",
    "Goldenshield",
    "Goldenstrike",
    "Hammersong",
    "Hammerstone",
    "Hammerstrike",
    "Honedblade",
    "Honorbound",
    "Honorforge",
    "Honorforged",
    "Honorshaper",
    "Honorstone",
    "Honorthane",
    "Ironbrew",
    "Ironfist",
    "Ironheart",
    "Ironhelm",
    "Ironshield",
    "Ironthane",
    "Ironvein",
    "Ironward",
    "Ironweaver",
    "Ironwhisper",
    "Ironwind",
    "Jadebeard",
    "Jadegrip",
    "Jadegrove",
    "Jadehelm",
    "Jadestar",
    "Jadestone",
    "Jadethane",
    "Jadetide",
    "Jewelsmith",
    "Jewelstrike",
    "Keenaxe",
    "Keeneye",
    "Kingshaper",
    "Kingshield",
    "Kingsmith",
    "Kingsong",
    "Kingsword",
    "Lightfoot",
    "Lionmantle",
    "Lionroar",
    "Longbeard",
    "Longstride",
    "Lorebeard",
    "Lorehammer",
    "Lorekeeper",
    "Loreward",
    "Loreweaver",
    "Lorewood",
    "Mithrilhelm",
    "Mithrilsmith",
    "Moltenheart",
    "Mountainbrow",
    "Mountainfall",
    "Mountainguard",
    "Mountainhelm",
    "Mountainsmith",
    "Mountainstone",
    "Mountainward",
    "Oakenforge",
    "Oakenshaper",
    "Oakenshield",
    "Oakensong",
    "Oakenstone",
    "Oathbearer",
    "Oathbound",
    "Oathkeeper",
    "Oathsworn",
    "Pikebeard",
    "Pinebranch",
    "Pinegrove",
    "Pinehammer",
    "Pineheart",
    "Pinehewer",
    "Pinerunner",
    "Pinetide",
    "Pinevein",
    "Proudbeard",
    "Proudhammer",
    "Quicksteel",
    "Quickstride",
    "Quickstrike",
    "Rockbreaker",
    "Rockcrusher",
    "Rockjaw",
    "Rocksplitter",
    "Runebeard",
    "Runebearer",
    "Runebinder",
    "Runeforge",
    "Runeguard",
    "Runehammer",
    "Runesmith",
    "Starkstone",
    "Stoneborn",
    "Stonehammer",
    "Stonehelm",
    "Stoneshaper",
    "Stoneshield",
    "Stonestorm",
    "Stonestrike",
    "Stonevein",
    "Stonewhisper",
    "Stoutbeard",
    "Thundereye",
    "Thunderfoot",
    "Thunderforge",
    "Thundershard",
    "Thundershield",
    "Thunderstone",
    "Thunderstorm",
    "Thundertide",
    "Thunderward",
    "Truesteel",
    "Truestrike",
    "Whisperbeard",
    "Whitestone",
    "Whitewind",
    "Whitewood",
    "Wildheart",
    "Wildstone",
    "Wildthane",
    "Wildward",
    "Wildwind",
    "Windgrip",
    "Windhelm",
    "Yewbark",
    "Yewblade",
    "Yewbranch",
    "Yewheart",
    "Yewhelm",
    "Yewmane",
    "Yewshield",
    "Yewstrike",
]

female = generate_female_name(female_prefix, female_suffix, min=1, max=2)
male = generate_male_name(male_prefix, male_suffix, min=1, max=1)
surname = generate_surname(surname_syllables, min=1, max=3)

female_lbr = choice(female_names)
male_lbr = choice(male_names)
surname_lbr = choice(surnames)



from random import choice
from .supportive_functions import (
    generate_female_name,
    generate_male_name,
    generate_surname_less,
    remove_duplicates,
)


female_prefix = [
    "aer",
    "ash",
    "bri",
    "cer",
    "daen",
    "ela",
    "for",
    "gwe",
    "hel",
    "iri",
    "jen",
    "kal",
    "lyn",
    "mel",
    "ny",
    "oth",
    "pae",
    "qua",
    "rin",
    "san",
    "the",
    "uil",
    "val",
    "wyr",
    "xan",
    "yen",
    "zoe",
]

female_suffix = [
    "a",
    "ah",
    "ara",
    "beth",
    "cia",
    "dra",
    "elle",
    "fira",
    "ga",
    "hanna",
    "ia",
    "jara",
    "kara",
    "lyn",
    "ma",
    "na",
    "ora",
    "phine",
    "qua",
    "ra",
    "selle",
    "thya",
    "ura",
    "vira",
    "wyn",
    "ya",
    "zara",
]

male_prefix = [
    "aeg",
    "bar",
    "ben",
    "bran",
    "daen",
    "dav",
    "edd",
    "gar",
    "jaq",
    "jon",
    "khal",
    "lor",
    "mor",
    "ned",
    "qua",
    "rob",
    "sam",
    "theon",
    "tor",
    "tyr",
    "vis",
]

male_suffix = [
    "ard",
    "as",
    "dor",
    "en",
    "erion",
    "frey",
    "gar",
    "gold",
    "gon",
    "hard",
    "is",
    "jen",
    "lan",
    "len",
    "man",
    "mar",
    "men",
    "mond",
    "nard",
    "on",
    "or",
    "red",
    "rick",
    "ros",
    "sen",
    "son",
    "ton",
    "ton",
    "ver",
    "win",
]

surname_prefix = [
    "bar",
    "bel",
    "black",
    "bran",
    "bron",
    "cor",
    "dor",
    "grey",
    "har",
    "kar",
    "lan",
    "lor",
    "mor",
    "nor",
    "red",
    "rey",
    "sta",
    "star",
    "tar",
    "thor",
    "tyr",
    "var",
    "vel",
    "west",
    "win",
    "ar",
    "ber",
    "cad",
    "con",
    "dorn",
    "dur",
    "fay",
    "gar",
    "hol",
    "jor",
    "karl",
    "ly",
    "mal",
    "nar",
    "ran",
    "ren",
    "san",
    "sel",
    "thorn",
    "ven",
    "ver",
    "war",
    "wil",
    "ya",
    "yor",
    "zor",
]

surname_suffix = [
    "borne",
    "croft",
    "dale",
    "field",
    "ford",
    "gate",
    "helm",
    "hold",
    "horn",
    "keep",
    "lock",
    "ridge",
    "rock",
    "run",
    "shaw",
    "stead",
    "stone",
    "wall",
    "water",
    "well",
    "wood",
    "ark",
    "crest",
    "don",
    "ford",
    "glen",
    "ham",
    "hart",
    "holt",
    "land",
    "mont",
    "more",
    "port",
    "rick",
    "sage",
    "shire",
    "son",
    "ton",
    "ville",
    "ward",
    "wick",
    "wood",
    "worth",
    "wyn",
    "yard",
    "zell",
]

female_names = [
    "Alayaya",
    "Alerie",
    "Alleria",
    "Alys",
    "Alysanne",
    "Alyssa",
    "Arianne",
    "Arya",
    "Asha",
    "Barbara",
    "Bella",
    "Bellena",
    "Bellonara",
    "Bess",
    "Beth",
    "Bethany",
    "Brienne",
    "Brynden",
    "Cassella",
    "Catelyn",
    "Cersei",
    "Daenerys",
    "Delena",
    "Della",
    "Doreah",
    "Dyanna",
    "Elia",
    "Ellaria",
    "Galyeon",
    "Genna",
    "Gilly",
    "Janna",
    "Jeyne",
    "Joy",
    "Jyanna",
    "Leona",
    "Lyanna",
    "Lyra",
    "Lysa",
    "Maege",
    "Marei",
    "Margaery",
    "Meera",
    "Melara",
    "Melessa",
    "Melisandre",
    "Merianne",
    "Mirri",
    "Missandei",
    "Mordane",
    "Mya",
    "Myranda",
    "Myrcella",
    "Nan",
    "Nymeria",
    "Obara",
    "Olenna",
    "Osha",
    "Rhaella",
    "Rhaenyra",
    "Rhaenys",
    "Rohanne",
    "Rosamund",
    "Roslin",
    "Sansa",
    "Sarella",
    "Selyse",
    "Septa",
    "Shae",
    "Shiera",
    "Shireen",
    "Taena",
    "Talisa",
    "Tanda",
    "Tyene",
    "Tysha",
    "Val",
    "Valaena",
    "Visenya",
    "Yara",
    "Ygritte",
]

male_names = [
    "Alayaya",
    "Alerie",
    "Alleria",
    "Alys",
    "Alysanne",
    "Alyssa",
    "Arianne",
    "Arya",
    "Asha",
    "Barbara",
    "Bella",
    "Bellena",
    "Bellonara",
    "Bess",
    "Beth",
    "Bethany",
    "Brienne",
    "Brynden",
    "Cassella",
    "Catelyn",
    "Cersei",
    "Daenerys",
    "Delena",
    "Della",
    "Doreah",
    "Dyanna",
    "Elia",
    "Ellaria",
    "Galyeon",
    "Genna",
    "Gilly",
    "Janna",
    "Jeyne",
    "Joy",
    "Jyanna",
    "Leona",
    "Lyanna",
    "Lyra",
    "Lysa",
    "Maege",
    "Marei",
    "Margaery",
    "Meera",
    "Melara",
    "Melessa",
    "Melisandre",
    "Merianne",
    "Mirri",
    "Missandei",
    "Mordane",
    "Mya",
    "Myranda",
    "Myrcella",
    "Nan",
    "Nymeria",
    "Obara",
    "Olenna",
    "Osha",
    "Rhaella",
    "Rhaenyra",
    "Rhaenys",
    "Rohanne",
    "Rosamund",
    "Roslin",
    "Sansa",
    "Sarella",
    "Selyse",
    "Septa",
    "Shae",
    "Shiera",
    "Shireen",
    "Taena",
    "Talisa",
    "Tanda",
    "Tyene",
    "Tysha",
    "Val",
    "Valaena",
    "Visenya",
    "Yara",
    "Ygritte",
]

surnames = [
    "Allyrion",
    "Arryn",
    "Baratheon",
    "Blackmont",
    "Blackwood",
    "Bolton",
    "Bracken",
    "Brave",
    "Brune",
    "Buckwell",
    "Bulwer",
    "Cafferen",
    "Caron",
    "Cassel",
    "Cerwyn",
    "Clegane",
    "Clifton",
    "Conklyn",
    "Connington",
    "Costayne",
    "Crabb",
    "Crakehall",
    "Cuy",
    "Dalt",
    "Dayne",
    "Egen",
    "Farman",
    "Farwynd",
    "Flint",
    "Florent",
    "Forrester",
    "Fossoway",
    "Frey",
    "Gargalen",
    "Gaunt",
    "Gendry",
    "Glover",
    "Goodbrother",
    "Greyjoy",
    "Harlaw",
    "Heddle",
    "Hightower",
    "Holt",
    "Hornwood",
    "Karstark",
    "Lake",
    "Lannister",
    "Mallister",
    "Manderly",
    "Marbrand",
    "Martell",
    "Merryweather",
    "Mollen",
    "Mormont",
    "Musgood",
    "Osgrey",
    "Peckledon",
    "Piper",
    "Qorgyle",
    "Redwyne",
    "Reed",
    "Rogers",
    "Royce",
    "Rykker",
    "Ryswell",
    "Santagar",
    "Seaworth",
    "Selmy",
    "Slynt",
    "Stark",
    "Stokeworth",
    "Stone",
    "Targaryen",
    "Tarly",
    "Tarth",
    "Thorne",
    "Tollett",
    "Trant",
    "Tully",
    "Tyrell",
    "Umber",
    "Vaith",
    "Vance",
    "Westerling",
    "Wode",
    "Wylde",
    "Yarwyck",
    "Yronwood",
]

female = generate_female_name(female_prefix, female_suffix, min=0, max=1)
male = generate_male_name(male_prefix, male_suffix, min=0, max=1)
surname = generate_surname_less(surname_prefix, surname_suffix)

female_lbr = choice(female_names)
male_lbr = choice(male_names)
surname_lbr = choice(surnames)



from random import choice
from .supportive_functions import (
    generate_female_name,
    generate_male_name,
    remove_duplicates,
)


female_prefix = [
    "ada",
    "al",
    "am",
    "an",
    "bel",
    "beth",
    "ca",
    "ce",
    "cha",
    "da",
    "de",
    "dra",
    "ela",
    "el",
    "ema",
    "en",
    "fa",
    "fay",
    "ga",
    "ge",
    "gi",
    "ha",
    "he",
    "hi",
    "ila",
    "il",
    "ima",
    "in",
    "ja",
    "je",
    "ka",
    "ke",
    "ki",
    "la",
    "le",
    "li",
    "ma",
    "me",
    "mi",
    "na",
    "ne",
    "ni",
    "ola",
    "ol",
    "oma",
    "pa",
    "pe",
    "pi",
    "qua",
    "ra",
    "re",
    "ri",
    "sa",
    "se",
    "sha",
    "ta",
    "te",
    "tha",
    "u",
    "va",
    "ve",
    "vi",
    "wa",
    "we",
    "wi",
    "ya",
    "ye",
    "yi",
    "za",
    "ze",
    "zi",
]

female_suffix = [
    "a",
    "ana",
    "ara",
    "beth",
    "ca",
    "cel",
    "cia",
    "da",
    "dora",
    "e",
    "ella",
    "fa",
    "fay",
    "ga",
    "gine",
    "ha",
    "hilda",
    "ia",
    "ina",
    "ira",
    "la",
    "lina",
    "lissa",
    "ma",
    "mia",
    "na",
    "ne",
    "nia",
    "nissa",
    "ola",
    "ona",
    "ora",
    "pa",
    "pia",
    "ra",
    "ria",
    "rina",
    "sa",
    "sina",
    "sta",
    "ta",
    "tia",
    "trina",
    "va",
    "via",
    "vina",
    "wa",
    "wena",
    "wilda",
    "ya",
    "yna",
    "yra",
    "za",
    "zia",
    "zina",
]

male_prefix = [
    "al",
    "ar",
    "ben",
    "cor",
    "dan",
    "el",
    "fin",
    "gar",
    "hir",
    "ian",
    "jam",
    "kil",
    "lin",
    "mor",
    "nix",
    "or",
    "per",
    "quin",
    "ron",
    "sam",
    "ter",
    "ul",
    "ver",
    "wes",
    "xan",
    "yor",
    "zach",
]

male_suffix = [
    "ald",
    "bert",
    "cor",
    "dard",
    "el",
    "finn",
    "gald",
    "hart",
    "ian",
    "jack",
    "kyle",
    "land",
    "mack",
    "nald",
    "orin",
    "paul",
    "quin",
    "rick",
    "sam",
    "tin",
    "ulph",
    "vald",
    "wick",
    "xander",
    "yor",
    "zeph",
]

female_names = [
    "Alecto",
    "Alice",
    "Alicia",
    "Andromeda",
    "Angelina",
    "Arabella",
    "Ariana",
    "Astoria",
    "Augusta",
    "Aurora",
    "Bellatrix",
    "Bertha",
    "Cassandra",
    "Cedrella",
    "Charity",
    "Cho",
    "Daisy",
    "Demelza",
    "Dolores",
    "Eloise",
    "Fleur",
    "Fridwulfa",
    "Ginny",
    "Hannah",
    "Helena",
    "Helga",
    "Hermione",
    "Lavender",
    "Lily",
    "Luna",
    "Lysandra",
    "Madam",
    "Mafalda",
    "Marietta",
    "Marlene",
    "Merope",
    "Millicent",
    "Minerva",
    "Molly",
    "Morag",
    "Myrtle",
    "Narcissa",
    "Nymphadora",
    "Padma",
    "Pansy",
    "Parvati",
    "Penelope",
    "Petunia",
    "Pomona",
    "Poppy",
    "Rita",
    "Romilda",
    "Rosalind",
    "Rowena",
    "Roxanne",
    "Sybill",
    "Wilhelmina",
]

male_names = [
    "Aberforth",
    "Abraxas",
    "Alastor",
    "Albert",
    "Albus",
    "Amicus",
    "Amos",
    "Amycus",
    "Antonin",
    "Argus",
    "Arthur",
    "Augustus",
    "Avery",
    "Axel",
    "Barnabas",
    "Bartemius",
    "Barty",
    "Basil",
    "Bilius",
    "Bill",
    "Cadmus",
    "Caius",
    "Cassius",
    "Cedric",
    "Charlie",
    "Charlus",
    "Chorley",
    "Colin",
    "Cormac",
    "Cornelius",
    "Damocles",
    "Dawlish",
    "Dean",
    "Dedalus",
    "Dennis",
    "Derek",
    "Devlin",
    "Dexter",
    "Diggle",
    "Dilys",
    "Dimitrov",
    "Dirk",
    "Dobby",
    "Draco",
    "Drystan",
    "Dudley",
    "Elphias",
    "Emeric",
    "Enoch",
    "Ernest",
    "Ernie",
    "Everard",
    "Fabian",
    "Fabius",
    "Falco",
    "Fenrir",
    "Filch",
    "Filius",
    "Finnigan",
    "Fletcher",
    "Flint",
    "Flitwick",
    "Florean",
    "Florian",
    "Florius",
    "Frank",
    "Fred",
    "Fudge",
    "Garrick",
    "Gawain",
    "Gellert",
    "George",
    "Gideon",
    "Gilderoy",
    "Godric",
    "Golpalott",
    "Goyle",
    "Granville",
    "Gregorovitch",
    "Gregory",
    "Griphook",
    "Grogan",
    "Grubbly",
    "Hagrid",
    "Halbert",
    "Hambledon",
    "Hargid",
    "Harkiss",
    "Harry",
    "Hector",
    "Hedwig",
    "Hengist",
    "Hepzibah",
    "Horace",
    "Humphrey",
    "Ignatius",
    "Igor",
    "Isolt",
    "James",
    "John",
    "Justin",
    "Kane",
    "Kingsley",
    "Kirley",
    "Kreacher",
    "Lee",
    "Leopold",
    "Lucius",
    "Ludo",
    "Lupin",
    "Lysander",
    "Marcus",
    "Marius",
    "Michael",
    "Miles",
    "Mondy",
    "Morfin",
    "Mundungus",
    "Myron",
    "Neville",
    "Newt",
    "Nicholas",
    "Nigel",
    "Nott",
    "Oliver",
    "Ollivander",
    "Olympe",
    "Orion",
    "Percy",
    "Peter",
    "Phineas",
    "Piers",
    "Pius",
    "Quirinus",
    "Rab",
    "Rabastan",
    "Ragnok",
    "Ralph",
    "Regulus",
    "Remus",
    "Rodolphus",
    "Roger",
    "Ron",
    "Rubeus",
    "Rufus",
    "Scorpius",
    "Seamus",
    "Septimus",
    "Severus",
    "Sirius",
    "Stan",
    "Sturgis",
    "Ted",
    "Terence",
    "Theodore",
    "Thorfinn",
    "Tiberius",
    "Tom",
    "Ulick",
    "Urquhart",
    "Vernon",
    "Viktor",
    "Vincent",
    "Walden",
    "Westcott",
    "Wilhelm",
    "Wilkie",
    "Winky",
    "Xenophilius",
    "Yaxley",
    "Zacharias",
]

surnames = [
    "Abbott",
    "Abercrombie",
    "Ackerley",
    "Ackerly",
    "Allinson",
    "Almeida",
    "Appleby",
    "Aragon",
    "Archer",
    "Avery",
    "Axminster",
    "Baddock",
    "Bagman",
    "Bagnold",
    "Bagshot",
    "Baron",
    "Baruffio",
    "Basil",
    "Bassat",
    "Beedle",
    "Belby",
    "Bell",
    "Benjy",
    "Bertram",
    "Binns",
    "Black",
    "Blane",
    "Bletchley",
    "Blishwick",
    "Bode",
    "Bones",
    "Boot",
    "Borchart",
    "Bosworth",
    "Branstone",
    "Braveheart",
    "Briar",
    "Bridges",
    "Brocklehurst",
    "Broderick",
    "Brown",
    "Brownstone",
    "Bryce",
    "Bulstrode",
    "Buncle",
    "Burbage",
    "Caddock",
    "Caldwell",
    "Camestros",
    "Campbell",
    "Carneirus",
    "Carrow",
    "Cattermole",
    "Cauldwell",
    "Chadwick",
    "Challenger",
    "Chang",
    "Chapman",
    "Chigley",
    "Chittock",
    "Choudhury",
    "Clagge",
    "Clench",
    "Cobb",
    "Cole",
    "Coleman",
    "Colquhoun",
    "Comstock",
    "Coote",
    "Cornfoot",
    "Crabbe",
    "Cragg",
    "Crane",
    "Creevey",
    "Cresswell",
    "Croaker",
    "Croker",
    "Cross",
    "Crouch",
    "Crowdy",
    "Crup",
    "Dankworth",
    "Dawlish",
    "Dearborn",
    "Delacour",
    "Dell",
    "Diggory",
    "Dippet",
    "Dobbs",
    "Dobson",
    "Docherty",
    "Doge",
    "Dolohov",
    "Dorkins",
    "Dornton",
    "Doyle",
    "Dribble",
    "Droslock",
    "Dudley",
    "Dumbledore",
    "Dunbar",
    "Dungworth",
    "Durant",
    "Dursley",
    "Edgecombe",
    "Edmonds",
    "Edwards",
    "Elder",
    "Elias",
    "Ellis",
    "Elphick",
    "Elphinstone",
    "Everard",
    "Farley",
    "Farthing",
    "Fat",
    "Fawcett",
    "Featherstone",
    "Figg",
    "Filch",
    "Finch",
    "Finch-Fletchley",
    "Finnigan",
    "Firenze",
    "Fisher",
    "Fitz",
    "Fitzroy",
    "Fleet",
    "Flint",
    "Fogarty",
    "Foley",
    "Fonseca",
    "Fontaine",
    "Forbisher",
    "Ford",
    "Fortescue",
    "Foster",
    "Foulkes",
    "Fowler",
    "Foy",
    "Fraser",
    "French",
    "Friar",
    "Frump",
    "Fudge",
    "Fuller",
    "Gaia",
    "Galatea",
    "Gambol",
    "Gamp",
    "Gaunt",
    "Gibbon",
    "Gideon",
    "Gilbert",
    "Gillywater",
    "Glanmore",
    "Glanvill",
    "Gleeson",
    "Glover",
    "Gold",
    "Goldstein",
    "Gonville",
    "Gordon",
    "Gormless",
    "Goshawk",
    "Gossamer",
    "Goudge",
    "Goujon",
    "Goyle",
    "Graham",
    "Granger",
    "Grant",
    "Grantham",
    "Graves",
    "Green",
    "Greengrass",
    "Greenleaf",
    "Greenway",
    "Gregory",
    "Grimblehawk",
    "Grimsditch",
    "Grindelwald",
    "Griselda",
    "Grosswort",
    "Grubbly-Plank",
    "Grunnion",
    "Gudgeon",
    "Gudrun",
    "Gumboil",
    "Gwenog",
    "Hagrid",
    "Halifax",
    "Halstead",
    "Hamilton",
    "Hammerhead",
    "Hampshire",
    "Handy",
    "Hargreaves",
    "Harp",
    "Harper",
    "Harris",
    "Harrow",
    "Hart",
    "Hattersley",
    "Haverstock",
    "Hawthorne",
    "Hayes",
    "Haywood",
    "Hazard",
    "Hecklin",
    "Hedges",
    "Hemming",
    "Hermes",
    "Higglebottom",
    "Higgs",
    "Highfield",
    "Hill",
    "Hillyard",
    "Hodson",
    "Hoggett",
    "Hogwarts",
    "Holborne",
    "Hole",
    "Honey",
    "Hooch",
    "Hookum",
    "Hopkins",
    "Hopkirk",
    "Hoppy",
    "Hornby",
    "Hornung",
    "Horton",
    "Humphrey",
    "Hunt",
    "Hunter",
    "Hutchinson",
    "Huxtable",
    "Ibsen",
    "Ichabod",
    "Impett",
    "Inglebee",
    "Inglethorp",
    "Innes",
    "Intosh",
    "Irons",
    "Isaacs",
    "Ivanova",
    "Ives",
    "Jackman",
    "Jackson",
    "Jacobs",
    "Jaffa",
    "Jenkins",
    "Jenks",
    "Jigger",
    "Johnson",
    "Jolli",
    "Jonas",
    "Jones",
    "Jordan",
    "Jorkins",
    "Juggins",
    "Jugson",
    "Junction",
    "Justice",
    "Jynx",
    "Kaino",
    "Kamkar",
    "Kappa",
    "Karkaroff",
    "Kettleburn",
    "Kidd",
    "Kieron",
    "Killough",
    "King",
    "Kingsley",
    "Kingsnorth",
    "Kirke",
    "Kirkegaard",
    "Kneen",
    "Knibbs",
    "Knott",
    "Knottingley",
    "Knowe",
    "Kramer",
    "Kray",
    "Krum",
    "Krumb",
    "Lacewing",
    "Lackaday",
    "Lancaster",
    "Landsman",
    "Langley",
    "Larkin",
    "LeFevre",
    "Leander",
    "Leek",
    "Leigh",
    "Leitman",
    "Lemon",
    "Lestrange",
    "Levenstein",
    "Levesque",
    "Liddell",
    "Limpet",
    "Littlehales",
    "Lively",
    "Llewellyn",
    "Llewelyn",
    "Lloyd",
    "Lockhart",
    "Lodge",
    "Logan",
    "Long",
    "Longbottom",
    "Longstaff",
    "Lovegood",
    "Lovegrove",
    "Lovett",
    "Lu",
    "Ludovic",
    "Lugwort",
    "Lumby",
    "Lupin",
    "Lupus",
    "Luther",
    "Lynch",
    "Mac",
    "MacAvoy",
    "MacBain",
    "MacBoon",
    "MacCarthy",
    "MacDougal",
    "MacDuff",
    "MacFusty",
    "MacGuffin",
    "MacGuffock",
    "MacHine",
    "MacKinnon",
    "MacKleduff",
    "MacNair",
    "MacNally",
    "MacPherson",
    "MacRory",
    "MacTavish",
    "MacVicar",
    "MacWhirter",
    "Macdonald",
    "Macmillan",
    "Macready",
    "Madam",
    "Madley",
    "Malfoy",
    "Malkin",
    "Mallory",
    "Malone",
    "Mambo",
    "Manco",
    "Manx",
    "March",
    "Marchbanks",
    "Marchmon",
    "Marge",
    "Marples",
    "Mars",
    "Marsh",
    "Marshbanks",
    "Marsland",
    "Martian",
    "Mascarenas",
    "Mason",
    "Maxime",
    "McAllister",
    "McAuley",
    "McBride",
    "McCafferty",
    "McCain",
    "McCann",
    "McClary",
    "McCluck",
    "McCluskey",
    "McCollum",
    "McCorquodale",
    "McCrae",
    "McCullen",
    "McCullough",
    "McDaid",
    "McDermott",
    "McDonald",
    "McDougal",
    "McDowell",
    "McElhinney",
    "McElligott",
    "McEvoy",
    "McFadden",
    "McFarlane",
    "McGarrigle",
    "McGinty",
    "McGonagall",
    "McGrath",
    "McGraw",
    "McGregor",
    "McGuinness",
    "McGuire",
    "McIntosh",
    "McKay",
    "McKechnie",
    "McKendrick",
    "McKenzie",
    "McKeown",
    "McKerrell",
    "McKinney",
    "McLaggen",
    "McLaren",
    "McLaughlin",
    "McLaurin",
    "McLeish",
    "McLeod",
    "McLoughlin",
    "McMackin",
    "McManus",
    "McMaster",
    "McMullan",
    "McMurphy",
    "McMurray",
    "McNab",
    "McNair",
    "McNamara",
    "McNaughton",
    "McNeill",
    "McNulty",
    "McPherson",
    "McQuillan",
    "McQuoid",
    "McRae",
    "McVitie",
    "Meadowes",
    "Meadows",
    "Melling",
    "Mellow",
    "Merrythought",
    "Mertin",
    "Metamorphus",
    "Middleton",
    "Mildew",
    "Mildmay",
    "Millar",
    "Millbank",
    "Milligan",
    "Mills",
    "Milner",
    "Milton",
    "Mintumble",
    "Miserden",
    "Misery",
    "Moffat",
    "Mojo",
    "Monaghan",
    "Moody",
    "Moon",
    "Mooney",
    "Moore",
    "Moran",
    "More",
    "Morgan",
    "Moriarty",
    "Morley",
    "Morlock",
    "Morrow",
    "Mortlake",
    "Mortlock",
    "Morton",
    "Mosby",
    "Moss",
    "Mostafa",
    "Mould",
    "Mouldywart",
    "Mudblood",
    "Muddle",
    "Muff",
    "Muffley",
    "Mulciber",
    "Mullet",
    "Mulready",
    "Mulvihill",
    "Mumbles",
    "Munslow",
    "Munson",
    "Munster",
    "Murdock",
    "Murphy",
    "Mush",
    "Mushy",
    "Musket",
    "Muskett",
    "Mystic",
    "Naggini",
    "Napier",
    "Napper",
    "Narkissos",
    "Nasty",
    "Naylor",
    "Needham",
    "Nellist",
    "Nellson",
    "Nelson",
    "Nelthorpe",
    "Nelwyn",
    "Nervosa",
    "Nettles",
    "Neville",
    "Newberry",
    "Newcomb",
    "Newman",
    "Newt",
    "Nickleby",
    "Niffler",
    "Nigger",
    "Nimrod",
    "Nipper",
    "Nitty",
    "Nixon",
    "Nobble",
    "Nodcock",
    "Noddle",
    "Noddy",
    "Noggin",
    "Nogood",
    "Noidea",
    "Nonsense",
    "Noodle",
    "Nooj",
    "Nook",
    "Nookingham",
    "Nopke",
    "Nork",
    "North",
    "Northbrook",
    "Northend",
    "Northfield",
    "Northman",
    "Norton",
    "Norwood",
    "Nott",
    "Nottley",
    "Novak",
    "Novelty",
    "Nudge",
    "Nugget",
    "Nuisance",
    "Nulbert",
    "Numbus",
    "Nunney",
    "Nutter",
    "Oakey",
    "Oakley",
    "Oblivion",
    "Oblong",
    "Obvious",
    "Ochre",
    "Ogle",
    "Ollerton",
    "Ollivander",
    "Ominous",
    "Onions",
    "Onslaught",
    "Opkirk",
    "Opworthy",
    "Oracle",
    "Orange",
    "Orchard",
    "Orlando",
    "Orton",
    "Orwell",
    "Ossory",
    "Othello",
    "Ott",
    "Otter",
    "Ottery",
    "Otton",
    "Ouldlodge",
    "Ouse",
    "Outhwaite",
    "Outlaw",
    "Outward",
    "Outwhistle",
    "Outwit",
    "Overland",
    "Owen",
    "Owens",
    "Oxford",
    "Oxfordshire",
    "Ozanne",
    "Paddock",
    "Parkinson",
    "Parseltongue",
    "Patil",
    "Peakes",
    "Peasegood",
    "Peebles",
    "Pepper",
    "Perkins",
    "Pettigrew",
    "Peverell",
    "Picquery",
    "Pike",
    "Pince",
    "Pippin",
    "Pirrip",
    "Pius",
    "Plunkett",
    "Podmore",
    "Pomfrey",
    "Ponsonby",
    "Potter",
    "Potts",
    "Poultney",
    "Prewett",
    "Price",
    "Pritchard",
    "Proudfoot",
    "Pruett",
    "Pucey",
    "Puddifoot",
    "Puffett",
    "Pulse",
    "Pye",
    "Quigley",
    "Quirke",
    "Quirrell",
    "Quist",
    "Quong",
    "Rabastan",
    "Radcliffe",
    "Ragnuk",
    "Rappaport",
    "Ravenclaw",
    "Rawle",
    "Reed",
    "Regulus",
    "Reiss",
    "Rellinger",
    "Rennervate",
    "Reynolds",
    "Rhodes",
    "Riddle",
    "Ripper",
    "Robards",
    "Robbins",
    "Roberts",
    "Robinson",
    "Rochfort",
    "Rockwood",
    "Rodriguez",
    "Rolanda",
    "Romilda",
    "Rookwood",
    "Roscoe",
    "Rose",
    "Rosier",
    "Rosmerta",
    "Runcorn",
    "Rusper",
    "Ruthven",
    "Ryan",
    "Ryddle",
    "Ryot",
    "Sabino",
    "Sacharissa",
    "Sagittarius",
    "Salazar",
    "Sallow",
    "Sampson",
    "Sanders",
    "Sanderson",
    "Sansa",
    "Santos",
    "Savage",
    "Saville",
    "Scabior",
    "Scamander",
    "Scarlett",
    "Scorpius",
    "Scrimgeour",
    "Scrimgour",
    "Seamus",
    "Seaton",
    "Selwyn",
    "Severus",
    "Shacklebolt",
    "Shafiq",
    "Shunpike",
    "Sidwell",
    "Sigrid",
    "Silva",
    "Silver",
    "Simms",
    "Sinistra",
    "Skeeter",
    "Skower",
    "Sloper",
    "Slughorn",
    "Slytherin",
    "Smallweed",
    "Smith",
    "Snape",
    "Sneeper",
    "Snyde",
    "Spangle",
    "Sparkle",
    "Sparkman",
    "Spencer",
    "Spinks",
    "Spinnet",
    "Spore",
    "Sprout",
    "Spryly",
    "Stamford",
    "Stanley",
    "Starling",
    "Stebbins",
    "Steele",
    "Stenner",
    "Stepney",
    "Stevens",
    "Stibbons",
    "Stimpson",
    "Stock",
    "Stoog",
    "Stooge",
    "Stooges",
    "Stoogis",
    "Stoogs",
    "Stoogy",
    "Strang",
    "Stratford",
    "Stroud",
    "Strykes",
    "Stump",
    "Sturgis",
    "Sulley",
    "Summers",
    "Sunninghill",
    "Surrey",
    "Sutcliffe",
    "Sutherland",
    "Sweet",
    "Swotter",
    "Sybill",
    "Talbot",
    "Tall",
    "Tamsin",
    "Tankworth",
    "Tarleton",
    "Tassell",
    "Tatting",
    "Tattle",
    "Tawny",
    "Teague",
    "Tempest",
    "Templeton",
    "Tentacula",
    "Terpsichore",
    "Terry",
    "Thicknesse",
    "Thistle",
    "Thomas",
    "Thomson",
    "Thorfinn",
    "Thornton",
    "Thrasher",
    "Threadneedle",
    "Thwaites",
    "Tibbles",
    "Tilcott",
    "Tillerman",
    "Timbers",
    "Timothy",
    "Tirza",
    "Titus",
    "Tofty",
    "Toke",
    "Tolipan",
    "Tonks",
    "Toothill",
    "Topsail",
    "Topsell",
    "Torpel",
    "Travers",
    "Trelawney",
    "Trickett",
    "Trinity",
    "Trionus",
    "Troy",
    "Truffle",
    "Truman",
    "Tuffnell",
    "Tugwood",
    "Tulipan",
    "Tulipan Sr.",
    "Tulipan Sr. Jr.",
    "Turner",
    "Turpin",
    "Twilfitt",
    "Twycross",
    "Umbridge",
    "Upton",
    "Urquhart",
    "Vaisey",
    "Valentine",
    "Vance",
    "Varley",
    "Vasey",
    "Veer",
    "Vekslar",
    "Vernon",
    "Vickers",
    "Vicky",
    "Victoria",
    "Vindictus",
    "Viridian",
    "Volant",
    "Voldemort",
    "Voles",
    "Vonderhaar",
    "Vosper",
    "Wagtail",
    "Walden",
    "Walker",
    "Wallace",
    "Walsingham",
    "Walton",
    "Wang",
    "Warbeck",
    "Ward",
    "Ware",
    "Warren",
    "Warrington",
    "Warwick",
    "Waterson",
    "Watkins",
    "Watson",
    "Weasley",
    "Weatherby",
    "Webber",
    "Webster",
    "Wedge",
    "Weedle",
    "Weedon",
    "Weezy",
    "Welch",
    "Weldon",
    "Wentworth",
    "Wepple",
    "West",
    "Westenberg",
    "Weston",
    "Whalen",
    "Wharton",
    "Wheeler",
    "Whelan",
    "Whipple",
    "Whisper",
    "White",
    "Whitfield",
    "Whitley",
    "Whitney",
    "Whitworth",
    "Whyte",
    "Wilberforce",
    "Wilbur",
    "Wilhelmina",
    "Wilkes",
    "Wilkins",
    "Wilkinson",
    "William",
    "Willis",
    "Willy",
    "Wilpert",
    "Wilson",
    "Wimple",
    "Wimpole",
    "Winchester",
    "Windle",
    "Winston",
    "Winter",
    "Wisteria",
    "Witchwood",
    "Witt",
    "Witterly",
    "Wolfe",
    "Wood",
    "Woodbine",
    "Woodbridge",
    "Woodcroft",
    "Woodruff",
    "Woodville",
    "Woollongong",
    "Wormtail",
    "Wormwood",
    "Worpel",
    "Wright",
    "Wurts",
    "Wycliff",
    "Xenophilius",
    "Yaxley",
    "Yewbeam",
    "York",
    "Yorke",
    "Young",
    "Yule",
    "Zabini",
    "Zacharias",
    "Zambini",
    "Zamojska",
    "Zamojski",
    "Zeller",
]

female = generate_female_name(female_prefix, female_suffix, min=1, max=1)
male = generate_male_name(male_prefix, male_suffix, min=1, max=1)
surname = choice(surnames)

female_lbr = choice(female_names)
male_lbr = choice(male_names)



from random import choice
from .supportive_functions import (
    generate_female_name,
    generate_male_name,
    remove_duplicates,
)


female_prefix = [
    "az",
    "barg",
    "bruz",
    "dolg",
    "drak",
    "gash",
    "ghor",
    "grish",
    "groth",
    "gul",
    "haz",
    "karg",
    "krash",
    "morg",
    "narg",
    "naz",
    "raz",
    "shag",
    "shar",
    "skar",
    "snag",
    "snar",
    "snaz",
    "thrak",
    "ug",
    "uruk",
    "varg",
    "zarg",
]

female_suffix = [
    "a",
    "ba",
    "da",
    "ga",
    "gga",
    "gla",
    "gra",
    "gsha",
    "gza",
    "ka",
    "kra",
    "la",
    "lga",
    "lka",
    "lsha",
    "mga",
    "mka",
    "nga",
    "nka",
    "nsha",
    "ra",
    "rak",
    "rga",
    "rka",
    "rsha",
    "sa",
    "sha",
    "ska",
    "sla",
    "tka",
    "tra",
    "tsha",
    "uka",
    "urka",
    "zga",
    "zka",
    "zsha",
]

male_prefix = [
    "az",
    "bal",
    "bolg",
    "dorg",
    "drak",
    "grom",
    "gruk",
    "gul",
    "karg",
    "kru",
    "laz",
    "log",
    "mog",
    "mok",
    "narg",
    "nok",
    "org",
    "rag",
    "rak",
    "shag",
    "shar",
    "skar",
    "skul",
    "snag",
    "snok",
    "thok",
    "thug",
    "thrak",
    "ug",
    "urk",
    "yaz",
    "yur",
]

male_suffix = [
    "dak",
    "dor",
    "gol",
    "grom",
    "gul",
    "karg",
    "krak",
    "kul",
    "lurk",
    "mok",
    "nak",
    "nok",
    "rag",
    "rak",
    "shak",
    "shok",
    "skar",
    "skul",
    "snik",
    "snok",
    "thak",
    "thok",
    "thug",
    "urk",
    "warg",
    "yak",
    "yuk",
    "zog",
]

surnames = [
    "Bor'ruk",
    "Darg'gash",
    "Dor'gon",
    "Drak'thul",
    "Drek'gash",
    "Drek'ka",
    "Drok'gar",
    "Drok'mog",
    "Dush'nak",
    "Gash'nak",
    "Gol'burz",
    "Gol'dur",
    "Gol'mok",
    "Gor'ak",
    "Gor'mok",
    "Grom'gul",
    "Kur'don",
    "Lug'gor",
    "Mog'ash",
    "Mog'dor",
    "Mog'lok",
    "Mok'gar",
    "Mol'dok",
    "Nar'gul",
    "Narg'hul",
    "Raz'nak",
    "Rok'gron",
    "Rok'mog",
    "Skul'gron",
    "Skul'mog",
    "Skul'rok",
    "Thrag'ash",
    "Thrak'gor",
    "Thruk'dar",
    "Thruk'dor",
    "Ur'burz",
    "Urz'gol",
    "Vor'gol",
    "Vor'grom",
    "Vor'shak",
    "Zog'dor",
    "Zog'gar",
    "Zogdu",
    "Zur'kosh",
]

female_names = [
    "Azogha",
    "Bashka",
    "Bazhga",
    "Borgula",
    "Brugha",
    "Dorashka",
    "Dorga",
    "Dorgha",
    "Dorgula",
    "Dorza",
    "Drogula",
    "Dugdush",
    "Dugha",
    "Dugula",
    "Durgarz",
    "Gashna",
    "Ghashka",
    "Ghazga",
    "Ghoragha",
    "Ghorga",
    "Gogla",
    "Golga",
    "Gorga",
    "Gorgula",
    "Gorka",
    "Gorza",
    "Gorzha",
    "Graga",
    "Grakga",
    "Grakha",
    "Grashka",
    "Grazha",
    "Grishna",
    "Grogula",
    "Grugula",
    "Grukha",
    "Grukka",
    "Gruna",
    "Guzhga",
    "Kazga",
    "Kazhga",
    "Korgula",
    "Kraga",
    "Kragula",
    "Krakka",
    "Krashka",
    "Krazga",
    "Krazha",
    "Krogla",
    "Krukka",
    "Krushna",
    "Lugdusha",
    "Mauzgash",
    "Mazhga",
    "Mogdush",
    "Mogha",
    "Mogula",
    "Mugdusha",
    "Mugha",
    "Mugla",
    "Mugula",
    "Muzga",
    "Muzgash",
    "Muzgha",
    "Nagha",
    "Nargha",
    "Nargula",
    "Nashga",
    "Nashgrodha",
    "Nashka",
    "Nazhga",
    "Nokha",
    "Norgula",
    "Nugdusha",
    "Nugha",
    "Nugula",
    "Nuzga",
    "Shagra",
    "Shagula",
    "Shakka",
    "Shakra",
    "Sharka",
    "Shazga",
    "Snagha",
    "Snagula",
    "Snashga",
    "Snazha",
    "Snogula",
    "Thogla",
    "Thogula",
    "Thokka",
    "Thragla",
    "Thraza",
    "Thrazna",
    "Throgla",
    "Throkga",
    "Throkgula",
    "Throkha",
    "Throkka",
    "Thrukha",
    "Thugdusha",
    "Ugga",
    "Ugla",
    "Uglasha",
    "Ugula",
    "Urzogga",
    "Uzgasha",
    "Uzha",
    "Zagula",
    "Zashga",
    "Zashka",
    "Zazhga",
    "Zogga",
    "Zogha",
    "Zogula",
    "Zogzha",
    "Zugla",
    "Zugula",
    "Zuzha",
]

male_names = [
    "Azgog",
    "Bashnag",
    "Bolash",
    "Bolgakh",
    "Bolmog",
    "Bolug",
    "Borzog",
    "Burzash",
    "Buzgash",
    "Dorgakh",
    "Dorgor",
    "Dorgoth",
    "Durbat",
    "Durgash",
    "Dushgol",
    "Dushgor",
    "Dushgrish",
    "Dushnak",
    "Ghashdor",
    "Ghashdug",
    "Ghashduk",
    "Ghashnag",
    "Ghashnakh",
    "Ghashrak",
    "Ghazdush",
    "Ghazgol",
    "Ghazgor",
    "Ghorg",
    "Gimlak",
    "Gimnash",
    "Gimrak",
    "Gimrash",
    "Golgakh",
    "Golgash",
    "Golmog",
    "Golnaz",
    "Golug",
    "Gorbag",
    "Gorbagh",
    "Gorblag",
    "Gorblud",
    "Gorgakh",
    "Gorgash",
    "Gorgol",
    "Gorgrak",
    "Gorgrim",
    "Gorgrish",
    "Gorluk",
    "Gorzug",
    "Gothmog",
    "Gothuz",
    "Grishnakh",
    "Grumash",
    "Grushnakh",
    "Lagduf",
    "Lugdush",
    "Luggrish",
    "Lugmog",
    "Lugnash",
    "Lugor",
    "Mauhur",
    "Mazgash",
    "Maznash",
    "Mogar",
    "Mogulg",
    "Morgak",
    "Morgluk",
    "Mugash",
    "Murgash",
    "Nargash",
    "Narzog",
    "Narzug",
    "Razgash",
    "Raznak",
    "Raznash",
    "Rugnash",
    "Rugor",
    "Shagblud",
    "Shagdor",
    "Shagdug",
    "Shagdush",
    "Shaggor",
    "Shagnaz",
    "Shagrat",
    "Shargash",
    "Sharku",
    "Snaga",
    "Snargash",
    "Snash",
    "Snashnag",
    "Tharku",
    "Tharzog",
    "Uglog",
    "Uglug",
    "Ugluk",
    "Uglur",
    "Uruk",
    "Urzash",
    "Urzgash",
    "Urzog",
    "Urzogar",
    "Urzul",
    "Ushdug",
    "Ushgash",
    "Ushgol",
    "Ushnag",
    "Uzgash",
    "Uzgol",
    "Zargash",
    "Zargol",
    "Zugdug",
    "Zugdush",
    "Zugluk",
    "Zugmog",
    "Zugthak",
]

titles = [
    "the Annihilator",
    "the Ashmaker",
    "the Axe",
    "the Bane",
    "the Blackhand",
    "the Blade",
    "the Blight",
    "the Bloodbane",
    "the Bloodfang",
    "the Bloodscourge",
    "the Bloodthirsty",
    "the Bone",
    "the Bonecrusher",
    "the Brutal",
    "the Brute",
    "the Butcher",
    "the Conqueror",
    "the Corpsemaker",
    "the Crazed",
    "the Crusher",
    "the Darkblade",
    "the Darkheart",
    "the Deathbringer",
    "the Deathdealer",
    "the Deathgaze",
    "the Deathgrip",
    "the Deathmask",
    "the Desecrator",
    "the Desolation",
    "the Despair",
    "the Despoiler",
    "the Destroyer",
    "the Devourer",
    "the Dismemberer",
    "the Doom",
    "the Doombringer",
    "the Doomclaw",
    "the Doomgaze",
    "the Doomhammer",
    "the Fearmonger",
    "the Fierce",
    "the Fleshrend",
    "the Gloom",
    "the Gloomfang",
    "the Gorefist",
    "the Gorehowl",
    "the Gravewalker",
    "the Grim",
    "the Grimdark",
    "the Grimface",
    "the Grimjaw",
    "the Grimskull",
    "the Gruesome",
    "the Gutslicer",
    "the Harbinger",
    "the Hellraiser",
    "the Horned",
    "the Howler",
    "the Impaler",
    "the Inferno",
    "the Ironfist",
    "the Ironhide",
    "the Marauder",
    "the Maul",
    "the Mauler",
    "the Merciless",
    "the Mocker",
    "the Nightstalker",
    "the Pestilence",
    "the Pitiless",
    "the Plaguebringer",
    "the Plunderer",
    "the Rage",
    "the Rager",
    "the Rampage",
    "the Ravager",
    "the Rend",
    "the Ruin",
    "the Ruiner",
    "the Ruthless",
    "the Savage",
    "the Scar",
    "the Scarface",
    "the Scourge",
    "the Scrapper",
    "the Shadow",
    "the Shadowhand",
    "the Shatterer",
    "the Sinister",
    "the Skull",
    "the Skullcrusher",
    "the Skullsplitter",
    "the Slasher",
    "the Slaughterer",
    "the Slayer",
    "the Sludge",
    "the Smasher",
    "the Snarler",
    "the Spinebreaker",
    "the Spite",
    "the Stalker",
    "the Swiftblade",
    "the Throatripper",
    "the Tormentor",
    "the Torturer",
    "the Venom",
    "the Venomfang",
    "the Vex",
    "the Vicious",
    "the Vile",
    "the Warbringer",
    "the Warcry",
    "the Warg",
    "the Warlord",
    "the Wicked",
    "the Wound",
    "the Wrecking Ball",
]

female = generate_female_name(female_prefix, female_suffix, min=0, max=1)
male = generate_male_name(male_prefix, male_suffix, min=0, max=1)
surname = choice(titles)

female_lbr = choice(female_names)
male_lbr = choice(male_names)
surname_lbr = choice(surnames)



from random import choice
from .supportive_functions import (
    generate_female_name,
    generate_male_name,
    generate_surname_less,
    remove_duplicates,
)

female_prefix = [
    "ar",
    "bal",
    "bar",
    "bran",
    "dar",
    "dran",
    "feth",
    "gras",
    "har",
    "jaf",
    "kar",
    "krul",
    "mar",
    "nar",
    "par",
    "rak",
    "ras",
    "sar",
    "tar",
    "thas",
    "thul",
    "war",
    "yas",
    "zar",
]


female_suffix = [
    "a",
    "ah",
    "al",
    "an",
    "ar",
    "ara",
    "as",
    "ath",
    "aun",
    "aya",
    "az",
    "da",
    "dal",
    "dan",
    "dar",
    "de",
    "del",
    "din",
    "dra",
    "du",
    "dul",
    "e",
    "eh",
    "el",
    "en",
    "er",
    "eth",
    "i",
    "ia",
    "il",
    "in",
    "ir",
    "is",
    "ish",
    "ith",
    "l",
    "la",
    "le",
    "lin",
    "ma",
    "mal",
    "man",
    "mar",
    "na",
    "nah",
    "nal",
    "nan",
    "ne",
    "neh",
    "nir",
    "ra",
    "rah",
    "ral",
    "ran",
    "re",
    "reh",
    "ri",
    "rin",
    "sa",
    "sal",
    "san",
    "se",
    "sel",
    "sha",
    "shal",
    "shan",
    "she",
    "shen",
    "si",
    "sin",
    "ta",
    "tal",
    "tan",
    "te",
    "tel",
    "ti",
    "tin",
    "va",
    "val",
    "van",
    "ve",
    "vel",
    "vi",
    "vin",
    "ya",
    "yah",
    "yal",
    "yan",
    "ye",
    "yel",
    "yi",
    "yin",
    "za",
    "zal",
    "zan",
    "ze",
    "zel",
    "zi",
    "zin",
]

male_prefix = [
    "ba",
    "bal",
    "bek",
    "bo",
    "bor",
    "bro",
    "dar",
    "del",
    "dra",
    "en",
    "er",
    "far",
    "fel",
    "gol",
    "gra",
    "ha",
    "har",
    "ho",
    "hor",
    "kar",
    "kel",
    "kor",
    "ku",
    "kur",
    "lar",
    "lek",
    "lok",
    "ma",
    "mar",
    "mo",
    "mor",
    "nar",
    "nel",
    "nor",
    "o",
    "or",
    "ra",
    "ran",
    "ro",
    "ron",
    "sa",
    "sar",
    "so",
    "sor",
    "ta",
    "tar",
    "to",
    "tor",
    "ur",
    "us",
    "va",
    "var",
    "vo",
    "vor",
]

male_suffix = [
    "ak",
    "ar",
    "ek",
    "el",
    "en",
    "er",
    "ik",
    "ir",
    "is",
    "ith",
    "ok",
    "or",
    "os",
    "oth",
    "uk",
    "ul",
    "un",
    "ur",
    "us",
    "uth",
    "yk",
    "yr",
    "ys",
]


surname_prefix = [
    "an",
    "bak",
    "blak",
    "bol",
    "bran",
    "bruk",
    "dar",
    "del",
    "dor",
    "erik",
    "fel",
    "gol",
    "grak",
    "gul",
    "har",
    "hel",
    "hor",
    "jor",
    "kar",
    "kel",
    "kha",
    "kol",
    "kor",
    "krul",
    "kul",
    "lar",
    "lek",
    "mor",
    "mur",
    "nal",
    "nul",
    "phel",
    "por",
    "rak",
    "ruk",
    "sar",
    "sel",
    "sol",
    "tar",
    "tel",
    "thel",
    "tol",
    "tor",
    "ul",
    "vak",
    "val",
    "var",
    "ver",
    "vol",
    "vor",
    "wol",
    "yor",
    "zol",
]

# Harry Potter-based surname suffixes
surname_suffix = [
    "aak",
    "ak",
    "an",
    "ar",
    "ek",
    "en",
    "er",
    "ik",
    "in",
    "ir",
    "ok",
    "on",
    "ong",
    "or",
    "uk",
    "un",
    "ur",
]
female_names = [
    "Agthar",
    "Akkrona",
    "Aldrava",
    "Algrima",
    "Andra",
    "Aragrima",
    "Balgrava",
    "Balvara",
    "Baronda",
    "Beldra",
    "Bolgrima",
    "Boltha",
    "Brudella",
    "Brundella",
    "Calgrava",
    "Cragara",
    "Dandrella",
    "Dargonda",
    "Delgara",
    "Dolgonda",
    "Dorgrima",
    "Drivara",
    "Droglima",
    "Drombella",
    "Dugrana",
    "Eldra",
    "Eldraga",
    "Elgrima",
    "Elgrona",
    "Endra",
    "Ergrima",
    "Ertharra",
    "Fagrima",
    "Falvara",
    "Fimvara",
    "Folgrima",
    "Folgronda",
    "Frandra",
    "Frogrima",
    "Frundella",
    "Gagonda",
    "Galdra",
    "Galgrana",
    "Galgrima",
    "Garvara",
    "Geldra",
    "Globarra",
    "Golgrima",
    "Gondra",
    "Gorgrima",
    "Grigara",
    "Gromvara",
    "Grondra",
    "Grundra",
    "Haldra",
    "Halgrava",
    "Halgrima",
    "Haronda",
    "Heldra",
    "Holgara",
    "Holgonda",
    "Hugrava",
    "Hurgrima",
    "Hurvara",
    "Igdra",
    "Ignarra",
    "Ilgara",
    "Ilgrima",
    "Ingoldra",
    "Jalgrima",
    "Jalgronda",
    "Jogara",
    "Jurgara",
    "Kalgonda",
    "Kalgrava",
    "Kalgrima",
    "Kargrima",
    "Kelgrima",
    "Kolgara",
    "Kolvara",
    "Krugonda",
    "Lagrima",
    "Lalgrima",
    "Landra",
    "Lodrava",
    "Logrima",
    "Lugrana",
    "Magonda",
    "Maldra",
    "Malgrava",
    "Malgrima",
    "Meldra",
    "Mogara",
    "Molvara",
    "Naldrava",
    "Nalgronda",
    "Nargara",
    "Nargrima",
    "Nelgronda",
    "Noldra",
    "Nolgara",
    "Ogonda",
    "Olgara",
    "Olgrima",
    "Otharra",
    "Pandrella",
    "Peldra",
    "Polgrima",
    "Prundra",
    "Qalgrima",
    "Quogara",
    "Ragonda",
    "Ragrima",
    "Raldra",
    "Ralgrima",
    "Relgrima",
    "Roganda",
    "Rogvara",
    "Rugrana",
    "Rugrima",
    "Sagrima",
    "Saldra",
    "Salgara",
    "Sildra",
    "Sogara",
    "Solgrima",
    "Sorvara",
    "Tagonda",
    "Talgrava",
    "Talgrima",
    "Tandrella",
    "Telgrima",
    "Togonda",
    "Tolgara",
    "Tugrava",
    "Uldra",
    "Ulgrima",
    "Urgara",
    "Vagrima",
    "Valgronda",
    "Vandrella",
    "Veldra",
    "Vilgrima",
    "Voldra",
    "Wagrima",
    "Waldra",
    "Walvara",
    "Wolgara",
    "Wolgrana",
    "Xalgrima",
    "Xandra",
    "Xolgonda",
    "Yalgrima",
    "Yalgronda",
    "Yoldra",
    "Yolgara",
    "Zagrima",
    "Zalgrima",
    "Zeldra",
    "Zogara",
    "Zolgonda",
    "Zugrava",
]

male_names = [
    "Aggron",
    "Aldrek",
    "Argrim",
    "Avalg",
    "Avalk",
    "Baelgor",
    "Baldrum",
    "Barak",
    "Barkul",
    "Bjorn",
    "Bolgor",
    "Bolthar",
    "Borak",
    "Bromar",
    "Bromir",
    "Brondar",
    "Bronn",
    "Burgul",
    "Colbrand",
    "Dagrund",
    "Dakkor",
    "Dargul",
    "Dorgul",
    "Drokmar",
    "Drokthar",
    "Dromgar",
    "Dromir",
    "Dromm",
    "Eitri",
    "Eldgrim",
    "Eldor",
    "Eldrim",
    "Eldur",
    "Elgrim",
    "Eltan",
    "Elvar",
    "Fargrim",
    "Fellgor",
    "Flintrock",
    "Forgrim",
    "Fornir",
    "Forok",
    "Forrik",
    "Fragnar",
    "Gargul",
    "Garrak",
    "Garruk",
    "Garthok",
    "Garvik",
    "Gathok",
    "Gorkon",
    "Grenthar",
    "Hakkar",
    "Haldor",
    "Harkon",
    "Harok",
    "Harvar",
    "Havok",
    "Heldor",
    "Hrimnir",
    "Ingar",
    "Ingrum",
    "Ingvar",
    "Ivor",
    "Ivrek",
    "Ivrik",
    "Jarn",
    "Jarnok",
    "Jorrin",
    "Jotgar",
    "Jotnar",
    "Jotrik",
    "Jotunn",
    "Karok",
    "Karrok",
    "Karvik",
    "Korak",
    "Korgrim",
    "Kragh",
    "Kraghmar",
    "Kraglok",
    "Kragthor",
    "Kromm",
    "Lodur",
    "Lokgar",
    "Loknir",
    "Lokthar",
    "Lokur",
    "Lugnar",
    "Lugnur",
    "Lugrik",
    "Lurak",
    "Maulgar",
    "Mogrund",
    "Molgar",
    "Molgrim",
    "Molrik",
    "Molthar",
    "Morgon",
    "Morgrom",
    "Morkul",
    "Nargul",
    "Narvok",
    "Narzug",
    "Nordak",
    "Norgar",
    "Norin",
    "Norkar",
    "Norkul",
    "Norn",
    "Ogmund",
    "Orgron",
    "Orin",
    "Orvak",
    "Orvar",
    "Othgar",
    "Othok",
    "Othrik",
    "Polaris",
    "Ragnik",
    "Ragnor",
    "Rathgar",
    "Rathok",
    "Ravagor",
    "Rokar",
    "Skalm",
    "Skarr",
    "Skorgul",
    "Skuldir",
    "Skullgrim",
    "Thokk",
    "Thorgar",
    "Thorgon",
    "Thorgrak",
    "Thorgrim",
    "Thorngrim",
    "Thragor",
    "Threk",
    "Ulfar",
    "Ulfgar",
    "Urthak",
    "Urtok",
    "Uthok",
    "Uthrik",
    "Uthrok",
    "Uthvar",
    "Valkur",
    "Valnor",
    "Vargrim",
    "Vargul",
    "Varnok",
    "Vorag",
    "Vorak",
    "Vorgrim",
    "Vorlok",
    "Vorn",
    "Ymir",
    "Zanril",
    "Zarkor",
    "Zarvik",
    "Zogrim",
    "Zorgar",
    "Zorgrim",
    "Zugrim",
    "Zugthor",
    "Zulgar",
    "Zulgrim",
]

surnames = [
    "the Abomination",
    "the Annihilator",
    "the Behemoth",
    "the Berserker",
    "the Blade",
    "the Bloodthirsty",
    "the Breaker",
    "the Brutal",
    "the Brute",
    "the Butcher",
    "the Cataclysm",
    "the Chaos",
    "the Colossus",
    "the Conqueror",
    "the Corruptor",
    "the Cruel",
    "the Crusher",
    "the Dark",
    "the Deathbringer",
    "the Demolisher",
    "the Desecrator",
    "the Desolator",
    "the Despoiler",
    "the Destroyer",
    "the Devastator",
    "the Devourer",
    "the Diabolical",
    "the Dire",
    "the Dominator",
    "the Dread",
    "the Executioner",
    "the Ferocious",
    "the Fierce",
    "the Formidable",
    "the Fury",
    "the Goliath",
    "the Grim",
    "the Hateful",
    "the Havoc",
    "the Impaler",
    "the Implacable",
    "the Indomitable",
    "the Insatiable",
    "the Intimidator",
    "the Invincible",
    "the Juggernaut",
    "the Maleficent",
    "the Malevolent",
    "the Malicious",
    "the Malignant",
    "the Marauder",
    "the Mauler",
    "the Menace",
    "the Menacer",
    "the Merciless",
    "the Nefarious",
    "the Nightmare",
    "the Obliterator",
    "the Oblivion",
    "the Oppressor",
    "the Overlord",
    "the Pounder",
    "the Ravager",
    "the Reaper",
    "the Reaver",
    "the Relentless",
    "the Ruiner",
    "the Ruler",
    "the Ruthless",
    "the Savage",
    "the Scourge",
    "the Sinister",
    "the Slammer",
    "the Slasher",
    "the Slayer",
    "the Smasher",
    "the Stomper",
    "the Storm",
    "the Terror",
    "the Thunder",
    "the Treacherous",
    "the Twisted",
    "the Tyrant",
    "the Unrelenting",
    "the Unstoppable",
    "the Unyielding",
    "the Vanquisher",
    "the Venomous",
    "the Vicious",
    "the Vile",
    "the Warbringer",
    "the Warlord",
    "the Wicked",
]

female = generate_female_name(female_prefix, female_suffix, min=0, max=1)
male = generate_male_name(male_prefix, male_suffix, min=0, max=1)
surname = generate_surname_less(surname_prefix, surname_suffix)

female_lbr = choice(female_names)
male_lbr = choice(male_names)
surname_lbr = choice(surnames)



from random import choice
from .supportive_functions import (
    generate_female_name,
    generate_male_name,
    generate_surname_less,
    remove_duplicates,
)

female_prefix = [
    "a",
    "ad",
    "ah",
    "al",
    "ar",
    "as",
    "ay",
    "b",
    "ba",
    "be",
    "ca",
    "ce",
    "ci",
    "da",
    "de",
    "di",
    "e",
    "el",
    "em",
    "en",
    "er",
    "es",
    "ev",
    "f",
    "g",
    "ga",
    "ge",
    "gi",
    "gu",
    "h",
    "ha",
    "i",
    "il",
    "is",
    "k",
    "ka",
    "ke",
    "ki",
    "ko",
    "ku",
    "l",
    "la",
    "le",
    "li",
    "lu",
    "m",
    "ma",
    "me",
    "mi",
    "mu",
    "n",
    "na",
    "ne",
    "ni",
    "o",
    "or",
    "p",
    "r",
    "ra",
    "re",
    "ri",
    "ru",
    "s",
    "sa",
    "se",
    "si",
    "su",
    "t",
    "ta",
    "te",
    "ti",
    "u",
    "un",
    "ur",
    "us",
    "ut",
    "v",
    "ya",
    "ye",
    "yi",
    "yi",
    "yö",
    "yu",
    "z",
]

female_suffix = [
    "a",
    "an",
    "ay",
    "ça",
    "can",
    "ce",
    "çe",
    "dem",
    "den",
    "e",
    "el",
    "em",
    "en",
    "er",
    "es",
    "et",
    "gül",
    "han",
    "i",
    "il",
    "im",
    "in",
    "ir",
    "iş",
    "iz",
    "ka",
    "kan",
    "ke",
    "kiz",
    "la",
    "le",
    "li",
    "lik",
    "miş",
    "nur",
    "o",
    "ol",
    "ön",
    "öz",
    "ra",
    "re",
    "rin",
    "ru",
    "sa",
    "şan",
    "se",
    "si",
    "su",
    "tan",
    "te",
    "ti",
    "tu",
    "tül",
    "u",
    "ur",
    "ü",
    "ya",
    "ye",
    "yi",
    "yi",
    "yor",
    "yu",
    "z",
]

male_prefix = [
    "ah",
    "al",
    "ar",
    "ba",
    "be",
    "ca",
    "ce",
    "da",
    "de",
    "el",
    "em",
    "fa",
    "ga",
    "ge",
    "ha",
    "he",
    "ib",
    "ic",
    "id",
    "id",
    "ja",
    "je",
    "ka",
    "ke",
    "la",
    "le",
    "ma",
    "me",
    "na",
    "ne",
    "oğ",
    "ol",
    "or",
    "pa",
    "pe",
    "ra",
    "re",
    "sa",
    "se",
    "ta",
    "te",
    "uğ",
    "ul",
    "ur",
    "va",
    "ve",
    "ya",
    "ye",
    "za",
    "ze",
]

male_suffix = [
    "an",
    "ar",
    "at",
    "ay",
    "baş",
    "bay",
    "can",
    "dağ",
    "dem",
    "dil",
    "el",
    "er",
    "gün",
    "han",
    "kaç",
    "kan",
    "kara",
    "kar",
    "kurt",
    "köylü",
    "öz",
    "polat",
    "sari",
    "sel",
    "soy",
    "şah",
    "türk",
    "uçar",
    "ul",
    "uzun",
    "yil",
    "yildiz",
    "yüz",
    "zorlu",
]

surname_prefix = [
    "ak",
    "alp",
    "ar",
    "as",
    "ay",
    "bar",
    "bay",
    "boz",
    "can",
    "cev",
    "çak",
    "çel",
    "dağ",
    "dem",
    "dil",
    "doğ",
    "dur",
    "ege",
    "er",
    "ev",
    "gök",
    "güç",
    "han",
    "iş",
    "işik",
    "iz",
    "kaç",
    "kara",
    "kiliç",
    "kurt",
    "küz",
    "men",
    "öz",
    "pinar",
    "sancak",
    "sari",
    "savaş",
    "sevinç",
    "şah",
    "şen",
    "tek",
    "toprak",
    "tunç",
    "ul",
    "üstün",
    "yildiz",
    "yilmaz",
    "yoğun",
    "zor",
]

surname_suffix = [
    "ağa",
    "ak",
    "al",
    "an",
    "baş",
    "bay",
    "bek",
    "boğa",
    "çar",
    "dağ",
    "demir",
    "dil",
    "er",
    "göl",
    "güç",
    "han",
    "kaç",
    "kan",
    "kar",
    "kiliç",
    "köy",
    "kurt",
    "man",
    "oğlu",
    "öz",
    "pinar",
    "san",
    "sar",
    "savaş",
    "şan",
    "şen",
    "taş",
    "tepe",
    "tunç",
    "türk",
    "ul",
    "uş",
    "üz",
    "yalin",
    "yildiz",
    "yilmaz",
    "yoğun",
    "zade",
]

female_names = [
    "Ada",
    "Ahu",
    "Alev",
    "Arzu",
    "Asli",
    "Aydan",
    "Ayfer",
    "Ayla",
    "Aylin",
    "Ayten",
    "Ayça",
    "Ayşe",
    "Bahar",
    "Banu",
    "Belgin",
    "Belkis",
    "Bengü",
    "Berna",
    "Berrin",
    "Betül",
    "Beyza",
    "Bilge",
    "Binnaz",
    "Bircan",
    "Birsen",
    "Burcu",
    "Buse",
    "Candan",
    "Cansu",
    "Cemre",
    "Ceyda",
    "Ceylan",
    "Damla",
    "Defne",
    "Demet",
    "Deniz",
    "Derya",
    "Dilber",
    "Dilek",
    "Dudu",
    "Eda",
    "Ediz",
    "Ekin",
    "Elif",
    "Elmas",
    "Emel",
    "Emine",
    "Esin",
    "Esra",
    "Eylem",
    "Ezgi",
    "Fadime",
    "Fatma",
    "Feride",
    "Feyza",
    "Figen",
    "Filiz",
    "Gaye",
    "Gizem",
    "Gül",
    "Gülay",
    "Gülcan",
    "Gülden",
    "Gülen",
    "Güler",
    "Gülizar",
    "Gülperi",
    "Gülçin",
    "Gülşen",
    "Güneş",
    "Güzin",
    "Hale",
    "Handan",
    "Hazan",
    "Hülya",
    "Kader",
    "Kamile",
    "Kevser",
    "Lale",
    "Leyla",
    "Merve",
    "Meryem",
    "Müge",
    "Nalan",
    "Nergis",
    "Nermin",
    "Nil",
    "Nur",
    "Nuray",
    "Nurdan",
    "Nurten",
    "Oya",
    "Pakize",
    "Pelin",
    "Pinar",
    "Rabia",
    "Reyhan",
    "Seda",
    "Seher",
    "Selma",
    "Sevim",
    "Sevinç",
    "Simge",
    "Songül",
    "Su",
    "Sude",
    "Sultan",
    "Tülay",
    "Türkan",
    "Umay",
    "Yasemin",
    "Yeliz",
    "Yeşim",
    "Yildiz",
    "Yonca",
    "Yurdagül",
    "Zehra",
    "Zeliha",
    "Zerrin",
    "Zeynep",
    "Zübeyde",
    "Çiçek",
    "Çiğdem",
    "Özge",
    "Ümmü",
    "İclal",
    "İlknur",
    "İrem",
    "Şebnem",
    "Şenay",
    "Şermin",
    "Şule",
    "Şükran",
]

male_names = [
    "Abdullah",
    "Acun",
    "Adem",
    "Adnan",
    "Ahmed",
    "Ahmet",
    "Akin",
    "Ali",
    "Alp",
    "Alparslan",
    "Amin",
    "Amir",
    "Asaf",
    "Aslan",
    "Atilla",
    "Aydin",
    "Ayhan",
    "Aytaç",
    "Azat",
    "Aziz",
    "Aşina",
    "Bahadir",
    "Bariş",
    "Batu",
    "Bekir",
    "Berat",
    "Berkant",
    "Bilal",
    "Bozkurt",
    "Bumin",
    "Burhan",
    "Bülent",
    "Can",
    "Cengiz",
    "Cenk",
    "Cevher",
    "Cihan",
    "Cihat",
    "Cüneyt",
    "Davut",
    "Deniz",
    "Dinçer",
    "Doğan",
    "Dursun",
    "Dündar",
    "Emin",
    "Emir",
    "Emre",
    "Ender",
    "Ercüment",
    "Erol",
    "Ertuğrul",
    "Evren",
    "Eymen",
    "Fahri",
    "Faruk",
    "Fatih",
    "Feridun",
    "Gazi",
    "Gencay",
    "Gökhan",
    "Gökmen",
    "Göktürk",
    "Güven",
    "Hakan",
    "Hakki",
    "Halil",
    "Halis",
    "Hamdi",
    "Harun",
    "Hasan",
    "Hulusi",
    "Hüseyin",
    "Ibrahim",
    "Ismail",
    "Kaan",
    "Kadir",
    "Kamuran",
    "Kasim",
    "Kaya",
    "Kemal",
    "Kiliç",
    "Levent",
    "Lütfi",
    "Mahir",
    "Mazlum",
    "Mehmet",
    "Mert",
    "Muhammed",
    "Muhammet",
    "Murat",
    "Mustafa",
    "Necati",
    "Nevzat",
    "Nihat",
    "Orhan",
    "Orkun",
    "Osman",
    "Ozan",
    "Oğuz",
    "Poyraz",
    "Rahmi",
    "Ramazan",
    "Recep",
    "Riza",
    "Sadik",
    "Selahattin",
    "Selim",
    "Serdar",
    "Sultan",
    "Süleyman",
    "Talha",
    "Tarik",
    "Tarkan",
    "Tayfun",
    "Tayyar",
    "Timur",
    "Turgay",
    "Ufuk",
    "Umut",
    "Uğur",
    "Yasin",
    "Yavuz",
    "Yildirim",
    "Yildiz",
    "Yilmaz",
    "Zafer",
    "Zeki",
    "Ziya",
    "Ömer",
    "Önder",
    "Özcan",
    "İbrahim",
    "İlhan",
    "İlyas",
    "İrfan",
    "İskender",
    "İsmet",
    "Şahin",
    "Şevket",
]

surnames = [
    "Abacioğlu",
    "Akinci",
    "Aksoy",
    "Alparslan",
    "Arslan",
    "Ateş",
    "Atçeken",
    "Avci",
    "Aybar",
    "Aydin",
    "Ayhan",
    "Ağaoğlu",
    "Baltaci",
    "Bardakoğlu",
    "Bayik",
    "Bayraktar",
    "Bağriyanik",
    "Bekiroğlu",
    "Beyazit",
    "Beşikçi",
    "Bozkurt",
    "Boğa",
    "Büyükberber",
    "Dağdeviren",
    "Demir",
    "Demirci",
    "Derebey",
    "Dilaver",
    "Doğan",
    "Durmaz",
    "Ekinci",
    "Erdoğan",
    "Eren",
    "Ergin",
    "Eroğlu",
    "Erçetin",
    "Gedikoğlu",
    "Göktürk",
    "Gültekin",
    "Güney",
    "Gürsoy",
    "Haktanir",
    "Kaplan",
    "Karabulut",
    "Karadağ",
    "Karahan",
    "Kartal",
    "Kaya",
    "Keskin",
    "Kiliç",
    "Korkmaz",
    "Koç",
    "Kurt",
    "Kutlu",
    "Kutluay",
    "Kutluhan",
    "Köksal",
    "Mert",
    "Mirza",
    "Mutlu",
    "Noyan",
    "Okçu",
    "Pehlivan",
    "Sari",
    "Savaş",
    "Sağlam",
    "Seçkin",
    "Tayyar",
    "Taşci",
    "Taşkin",
    "Tekin",
    "Topal",
    "Topçu",
    "Tosun",
    "Tuğrul",
    "Türk",
    "Uludağ",
    "Uluçay",
    "Uysal",
    "Yalçin",
    "Yaman",
    "Yildirim",
    "Yildiz",
    "Yilmaz",
    "Yücel",
    "Zeybek",
    "Zorlu",
    "Zülfikar",
    "Zümrüt",
    "Çakir",
    "Çatalkaya",
    "Çelik",
    "Özdemir",
    "Özen",
    "Özkaya",
    "Özkök",
    "Öztürk",
    "Özyürek",
    "Ünal",
    "Üngör",
    "Üstün",
    "İlhan",
    "İnanç",
    "Şahin",
    "Şahsuvar",
    "Şeker",
    "Şen",
    "Şimşek",
]

female = generate_female_name(female_prefix, female_suffix, min=1, max=1)
male = generate_male_name(male_prefix, male_suffix, min=1, max=1)
surname = generate_surname_less(surname_prefix, surname_suffix)

female = generate_female_name(female_prefix, female_suffix, min=1, max=1)
male = generate_male_name(male_prefix, male_suffix, min=1, max=1)
surname = generate_surname_less(surname_prefix, surname_suffix)

female_lbr = choice(female_names)
male_lbr = choice(male_names)
surname_lbr = choice(surnames)

# print(remove_duplicates(surnames))

# for name in female_names:
#     print("'", name.capitalize(), "'", sep='', end=', ')



from . import arab, aztec, chinese, dwarven, elven, english, giant, halfling, japanese, mongolian, norsemen, orc, slavic, greek, steampunk, tolkien, viking, germanic, turkish, human, martin, jordan, erikson, roman, rowling, sapkowski
from random import choice

def generate_name(gender=choice(["female", "male"]), style="human", library=True):
    if type(gender) != str:
        raise TypeError("Invalid gender type.")
    if type(style) != str:
        raise TypeError("Invalid style type.")
    if type(library) != bool:
        raise TypeError("Invalid library type.")
    if gender.lower() == "female":
        match style:
            case "elven":
                name = elven.female if library is False else elven.female_lbr
            case "dwarven":
                name = dwarven.female if library is False else dwarven.female_lbr
            case "giant":
                name = giant.female if library is True else giant.female_lbr
            case "halfling":
                name = halfling.female if library is False else halfling.female_lbr
            case "orc":
                name = orc.female if library is False else orc.female_lbr
            case "steampunk":
                name = steampunk.female if library is False else steampunk.female_lbr
            case "human":
                name = human.female
            case "english":
                name = english.female if library is False else english.female_lbr
            case "greek":
                name = greek.female if library is False else greek.female_lbr
            case "norsemen":
                name = norsemen.female if library is False else norsemen.female_lbr
            case "arab":
                name = arab.female if library is False else arab.female_lbr
            case "japanese":
                name = japanese.female if library is False else japanese.female_lbr
            case "viking":
                name = viking.female if library is False else viking.female_lbr
            case "germanic":
                name = germanic.female if library is False else germanic.female_lbr
            case "turkish":
                name = turkish.female if library is False else turkish.female_lbr
            case "chinese":
                name = chinese.female if library is False else chinese.female_lbr
            case "mongolian":
                name = mongolian.female if library is False else mongolian.female_lbr
            case "slavic":
                name = slavic.female if library is False else slavic.female_lbr
            case "aztec":
                name = aztec.female if library is False else aztec.female_lbr
            case "roman":
                name = roman.female if library is False else roman.female_lbr
            case "tolkien":
                name = tolkien.female if library is False else tolkien.female_lbr
            case "martin":
                name = martin.female if library is False else martin.female_lbr
            case "jordan":
                name = jordan.female if library is False else jordan.female_lbr
            case "erikson":
                name = erikson.female if library is False else erikson.female_lbr
            case "rowling":
                name = rowling.female if library is False else rowling.female_lbr
            case "sapkowski":
                name = sapkowski.female if library is False else sapkowski.female_lbr
    elif gender.lower() == "male":
        match style:
            case "elven":
                name = elven.male if library is False else elven.male_lbr
            case "dwarven":
                name = dwarven.male if library is False else dwarven.male_lbr
            case "giant":
                name = giant.male if library is True else giant.male_lbr
            case "halfling":
                name = halfling.male if library is False else halfling.male_lbr
            case "orc":
                name = orc.male if library is False else orc.male_lbr
            case "steampunk":
                name = steampunk.male if library is False else steampunk.male_lbr
            case "human":
                name = human.male
            case "english":
                name = english.male if library is False else english.male_lbr
            case "greek":
                name = greek.male if library is False else greek.male_lbr
            case "norsemen":
                name = norsemen.male if library is False else norsemen.male_lbr
            case "arab":
                name = arab.male if library is False else arab.male_lbr
            case "japanese":
                name = japanese.male if library is False else japanese.male_lbr
            case "viking":
                name = viking.male if library is False else viking.male_lbr
            case "germanic":
                name = germanic.male if library is False else germanic.male_lbr
            case "turkish":
                name = turkish.male if library is False else turkish.male_lbr
            case "chinese":
                name = chinese.male if library is False else chinese.male_lbr
            case "mongolian":
                name = mongolian.male if library is False else mongolian.male_lbr
            case "slavic":
                name = slavic.male if library is False else slavic.male_lbr
            case "aztec":
                name = aztec.male if library is False else aztec.male_lbr
            case "roman":
                name = roman.male if library is False else roman.male_lbr
            case "tolkien":
                name = tolkien.male if library is False else tolkien.male_lbr
            case "martin":
                name = martin.male if library is False else martin.male_lbr
            case "jordan":
                name = jordan.male if library is False else jordan.male_lbr
            case "erikson":
                name = erikson.male if library is False else erikson.male_lbr
            case "rowling":
                name = rowling.male if library is False else rowling.male_lbr
            case "sapkowski":
                name = sapkowski.male if library is False else sapkowski.male_lbr
    else:
        raise ValueError("Invalid gender specified. Please choose 'male' or 'female'.")

    if style.lower() == "elven":
        surname = elven.surname if library is False else elven.surname_lbr
    elif style.lower() == "dwarven":
        surname = dwarven.surname if library is False else dwarven.surname_lbr
    elif style.lower() == "giant":
        surname = giant.surname if library is True else giant.surname_lbr
    elif style.lower() == "halfling":
        surname = halfling.surname if library is False else halfling.surname_lbr
    elif style.lower() == "orc":
        surname = orc.surname if library is False else orc.surname_lbr
    elif style.lower() == "steampunk":
        surname = steampunk.surname if library is False else steampunk.surname_lbr
    elif style.lower() == "human":
        surname = human.surname if library is False else human.surname_lbr
    elif style.lower() == "english":
        surname = english.surname if library is False else english.surname_lbr
    elif style.lower() == "greek":
        surname = greek.surname if library is False else greek.surname_lbr
    elif style.lower() == "norsemen":
        surname = norsemen.surname if library is False else norsemen.surname_lbr
    elif style.lower() == "arab":
        surname = arab.surname if library is False else arab.surname_lbr
    elif style.lower() == "japanese":
        surname = japanese.surname if library is False else japanese.surname_lbr
    elif style.lower() == "viking":
        surname = (
            viking.surname
            if library is False
            else (
                viking.female_surname_lbr
                if gender == "female"
                else viking.male_surname_lbr
            )
        )
    elif style.lower() == "germanic":
        surname = germanic.surname if library is False else germanic.surname_lbr
    elif style.lower() == "turkish":
        surname = turkish.surname if library is False else turkish.surname_lbr
    elif style.lower() == "chinese":
        surname = chinese.surname if library is False else chinese.surname_lbr
    elif style.lower() == "mongolian":
        surname = mongolian.surname if library is False else mongolian.surname_lbr
    elif style.lower() == "slavic":
        surname = slavic.surname if library is False else slavic.surname_lbr
    elif style.lower() == "aztec":
        surname = aztec.surname if library is False else aztec.surname_lbr
    elif style.lower() == "roman":
        surname = roman.surname if library is False else roman.surname_lbr
    elif style.lower() == "tolkien":
        surname = tolkien.surname if library is False else tolkien.surname_lbr
    elif style.lower() == "martin":
        surname = martin.surname if library is False else martin.surname_lbr
    elif style.lower() == "jordan":
        surname = jordan.surname if library is False else jordan.surname_lbr
    elif style.lower() == "erikson":
        surname = erikson.surname if library is False else erikson.surname_lbr
    elif style.lower() == "rowling":
        surname = rowling.surname
    elif style.lower() == "sapkowski":
        surname = sapkowski.surname if library is False else sapkowski.surname_lbr
    else:
        raise ValueError(
            "Invalid style specified. Please choose a valid style between 'elven', 'dwarven', 'giant', 'halfling', 'orc', 'steampunk', 'human', 'english', 'greek', 'norsemen', 'arab', 'japanese', 'viking', 'germanic', 'turkish', 'chinese', 'mongolian', 'slavic', 'aztec', 'roman', 'tolkien', 'martin', 'jordan', 'erikson', 'rowling', or 'sapkowski'."
        )

    return f"{name} {surname}"


if __name__ == "__main__":
    name = generate_name()
    print(name)
